@@ -121,7 +121,7 @@ public:
   kernel::activity::MailboxImpl* getImpl() { return pimpl_; }
 
   /** Gets the name of that mailbox */
-  const char *name();
+  const char* getName();
 
   /** Retrieve the mailbox associated to the given C string */
   static MailboxPtr byName(const char *name);
@@ -147,7 +147,29 @@ public:
   void setReceiver(ActorPtr actor);
 
   /** Return the actor declared as permanent receiver, or nullptr if none **/
-  ActorPtr receiver();
+  ActorPtr getReceiver();
+
+  /** Creates (but don't start) a data emission to that mailbox */
+  CommPtr put_init();
+  /** Creates (but don't start) a data emission to that mailbox */
+  CommPtr put_init(void* data, uint64_t simulatedSizeInBytes);
+  /** Creates and start a data emission to that mailbox */
+  CommPtr put_async(void* data, uint64_t simulatedSizeInBytes);
+
+  /** Blocking data emission */
+  void put(void* payload, uint64_t simulatedSizeInBytes);
+  /** Blocking data emission with timeout */
+  void put(void* payload, uint64_t simulatedSizeInBytes, double timeout);
+
+  /** Creates (but don't start) a data reception onto that mailbox */
+  CommPtr get_init();
+  /** Creates and start an async data reception to that mailbox */
+  CommPtr get_async(void** data);
+
+  /** Blocking data reception */
+  void* get();
+  /** Blocking data reception with timeout */
+  void* get(double timeout);
 };
 
 }} // namespace simgrid::s4u
