@@ -13,6 +13,8 @@ namespace simgrid {
 namespace s4u {
 
 class Actor;
+XBT_PUBLIC(void) intrusive_ptr_release(Actor* actor);
+XBT_PUBLIC(void) intrusive_ptr_add_ref(Actor* actor);
 using ActorPtr = boost::intrusive_ptr<Actor>;
 
 class Activity;
@@ -25,6 +27,7 @@ class Mailbox;
 using MailboxPtr = boost::intrusive_ptr<Mailbox>;
 class Mutex;
 class NetZone;
+class VirtualMachine;
 
 class File;
 class Storage;
