@@ -30,7 +30,6 @@ XBT_PUBLIC(int) xbt_os_get_numcores(void);
 typedef struct xbt_os_thread_ *xbt_os_thread_t;
 XBT_PUBLIC(xbt_os_thread_t) xbt_os_thread_create(const char *name, pvoid_f_pvoid_t start_routine, void *param, void *data);
 XBT_PUBLIC(void) xbt_os_thread_exit(int *retcode);
-XBT_PUBLIC(void) xbt_os_thread_detach(xbt_os_thread_t thread);
 
 XBT_PUBLIC(xbt_os_thread_t) xbt_os_thread_self(void);
 XBT_PUBLIC(const char *) xbt_os_thread_self_name(void);
@@ -42,7 +41,6 @@ XBT_PUBLIC(void*) xbt_os_thread_get_specific(xbt_os_thread_key_t key);
   /* xbt_os_thread_join frees the joined thread (ie the XBT wrapper around it, the OS frees the rest) */
 XBT_PUBLIC(void) xbt_os_thread_join(xbt_os_thread_t thread, void **thread_return);
 XBT_PUBLIC(void) xbt_os_thread_yield(void);
-XBT_PUBLIC(void) xbt_os_thread_cancel(xbt_os_thread_t thread);
 XBT_PUBLIC(void) xbt_os_thread_setstacksize(int stack_size);
 XBT_PUBLIC(void) xbt_os_thread_setguardsize(int guard_size);
 XBT_PUBLIC(int) xbt_os_thread_bind(xbt_os_thread_t thread, int core);
