@@ -1,11 +1,11 @@
-/* Copyright (c) 2010-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2010-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "src/instr/instr_private.h"
 #include "surf/surf.h"
+#include <string>
 #include <vector>
 
 XBT_LOG_NEW_CATEGORY(instr, "Logging the behavior of the tracing system (used for Visualization/Analysis of simulations)");
@@ -63,6 +63,8 @@ static int trace_precision;
 static bool trace_configured = false;
 static bool trace_active     = false;
 
+static simgrid::instr::Type* rootType = nullptr; /* the root type */
+
 instr_fmt_type_t instr_fmt_type = instr_fmt_paje;
 
 static void TRACE_getopts()
@@ -120,13 +122,6 @@ int TRACE_start()
     }
     trace_active = 1;
     XBT_DEBUG("Tracing is on");
-
-    /* other trace initialization */
-    created_categories = xbt_dict_new_homogeneous(xbt_free_f);
-    declared_marks = xbt_dict_new_homogeneous(xbt_free_f);
-    user_host_variables = xbt_dict_new_homogeneous(xbt_free_f);
-    user_vm_variables = xbt_dict_new_homogeneous(xbt_free_f);
-    user_link_variables = xbt_dict_new_homogeneous(xbt_free_f);
   }
   return 0;
 }
@@ -148,15 +143,8 @@ int TRACE_end()
 
     /* destroy all data structures of tracing (and free) */
     PJ_container_free_all();
-    PJ_type_free_all();
-    PJ_container_release();
-    PJ_type_release();
-
-    xbt_dict_free(&user_link_variables);
-    xbt_dict_free(&user_host_variables);
-    xbt_dict_free(&user_vm_variables);
-    xbt_dict_free(&declared_marks);
-    xbt_dict_free(&created_categories);
+    delete PJ_type_get_root();
+    rootType = nullptr;
 
     /* close the trace files */
     const char* format = xbt_cfg_get_string(OPT_TRACING_FORMAT);
@@ -313,7 +301,7 @@ char *TRACE_get_viva_cat_conf ()
   return xbt_cfg_get_string(OPT_VIVA_CAT_CONF);
 }
 
-void TRACE_global_init(int *argc, char **argv)
+void TRACE_global_init()
 {
   static int is_initialised = 0;
   if (is_initialised)
@@ -489,20 +477,19 @@ static void output_types (const char *name, xbt_dynar_t types, FILE *file)
   xbt_dynar_free (&types);
 }
 
-static void output_categories (const char *name, xbt_dynar_t cats, FILE *file)
+static void output_categories(const char* name, FILE* file)
 {
-  unsigned int i;
+  unsigned int i = created_categories.size();
   fprintf (file, "    values = (");
-  for (i = xbt_dynar_length(cats); i > 0; i--) {
-    char *cat = *(static_cast<char**>(xbt_dynar_get_ptr(cats, i - 1)));
-    fprintf (file, "\"%s%s\"", name, cat);
-    if (i - 1 > 0){
+  for (auto const& cat : created_categories) {
+    --i;
+    fprintf(file, "\"%s%s\"", name, cat.c_str());
+    if (i > 0) {
       fprintf (file, ",");
     }else{
       fprintf (file, ");\n");
     }
   }
-  xbt_dynar_free (&cats);
 }
 
 static void uncat_configuration (FILE *file)
@@ -539,13 +526,13 @@ static void cat_configuration (FILE *file)
            "  host = {\n"
            "    type = \"square\";\n"
            "    size = \"power\";\n");
-  output_categories ("p", TRACE_get_categories(), file);
+  output_categories("p", file);
   fprintf (file,
            "  };\n"
            "  link = {\n"
            "    type = \"rhombus\";\n"
            "    size = \"bandwidth\";\n");
-  output_categories ("b", TRACE_get_categories(), file);
+  output_categories("b", file);
   fprintf (file, "  };\n");
   //close
 }
@@ -572,7 +559,7 @@ static void generate_cat_configuration (const char *output, const char *name, in
 {
   if (output && strlen(output) > 0){
     //check if we do have categories declared
-    if (xbt_dict_is_empty(created_categories)){
+    if (created_categories.empty()) {
       XBT_INFO("No categories declared, ignoring generation of %s graph configuration", name);
       return;
     }
@@ -630,21 +617,3 @@ void instr_resume_tracing ()
   XBT_DEBUG ("Tracing is resumed.");
   previous_trace_state = -1;
 }
-
-#undef OPT_TRACING
-#undef OPT_TRACING_PLATFORM
-#undef OPT_TRACING_TOPOLOGY
-#undef OPT_TRACING_SMPI
-#undef OPT_TRACING_SMPI_GROUP
-#undef OPT_TRACING_CATEGORIZED
-#undef OPT_TRACING_UNCATEGORIZED
-#undef OPT_TRACING_MSG_PROCESS
-#undef OPT_TRACING_FILENAME
-#undef OPT_TRACING_BUFFER
-#undef OPT_TRACING_ONELINK_ONLY
-#undef OPT_TRACING_DISABLE_DESTROY
-#undef OPT_TRACING_BASIC
-#undef OPT_TRACING_COMMENT
-#undef OPT_TRACING_COMMENT_FILE
-#undef OPT_VIVA_UNCAT_CONF
-#undef OPT_VIVA_CAT_CONF
