@@ -6,7 +6,7 @@
 
 #include "src/instr/instr_private.h"
 #include "src/instr/instr_smpi.h"
-#include "src/smpi/private.hpp"
+#include "src/smpi/include/private.hpp"
 #include "typeinfo"
 #include "xbt/virtu.h" /* sg_cmdline */
 #include "simgrid/sg_config.h"
@@ -27,14 +27,8 @@ FILE *tracing_file = nullptr;
 static xbt_dict_t tracing_files = nullptr; // TI specific
 static double prefix=0.0; // TI specific
 
-
-void print_NULL(PajeEvent* event){}
-
-/* The active set of functions for the selected trace format
- * By default, they all do nothing, hence the print_NULL to avoid segfaults */
-
-std::vector<PajeEvent*> buffer;
-void buffer_debug(std::vector<PajeEvent*> *buf);
+std::vector<simgrid::instr::PajeEvent*> buffer;
+void buffer_debug(std::vector<simgrid::instr::PajeEvent*>* buf);
 
 void dump_comment (const char *comment)
 {
@@ -74,15 +68,15 @@ void TRACE_paje_dump_buffer (int force)
     return;
   XBT_DEBUG("%s: dump until %f. starts", __FUNCTION__, TRACE_last_timestamp_to_dump);
   if (force){
-    for (auto event : buffer){
+    for (auto const& event : buffer) {
       event->print();
       delete event;
     }
     buffer.clear();
   }else{
-    std::vector<PajeEvent*>::iterator i = buffer.begin();
-    for (auto event :buffer){
-      double head_timestamp = event->timestamp;
+    std::vector<simgrid::instr::PajeEvent*>::iterator i = buffer.begin();
+    for (auto const& event : buffer) {
+      double head_timestamp = event->timestamp_;
       if (head_timestamp > TRACE_last_timestamp_to_dump)
         break;
       event->print();
@@ -94,11 +88,12 @@ void TRACE_paje_dump_buffer (int force)
   XBT_DEBUG("%s: ends", __FUNCTION__);
 }
 
-void buffer_debug(std::vector<PajeEvent*> *buf);
-void buffer_debug(std::vector<PajeEvent*> *buf) {
+void buffer_debug(std::vector<simgrid::instr::PajeEvent*>* buf);
+void buffer_debug(std::vector<simgrid::instr::PajeEvent*>* buf)
+{
   return;
   XBT_DEBUG(">>>>>> Dump the state of the buffer. %zu events", buf->size());
-  for (auto event :*buf){
+  for (auto const& event : *buf) {
     event->print();
     XBT_DEBUG("%p %s", event, stream.str().c_str());
     stream.str("");
@@ -115,17 +110,18 @@ static void print_row() {
   stream.clear();
 }
 
-static void print_timestamp(PajeEvent* event) {
+static void print_timestamp(simgrid::instr::PajeEvent* event)
+{
   stream << " ";
   /* prevent 0.0000 in the trace - this was the behavior before the transition to c++ */
-  if (event->timestamp < 1e-12)
+  if (event->timestamp_ < 1e-12)
     stream << 0;
   else
-    stream << event->timestamp;
+    stream << event->timestamp_;
 }
 
 /* internal do the instrumentation module */
-static void insert_into_buffer (PajeEvent* tbi)
+static void insert_into_buffer(simgrid::instr::PajeEvent* tbi)
 {
   if (TRACE_buffer() == 0){
     tbi->print ();
@@ -134,14 +130,13 @@ static void insert_into_buffer (PajeEvent* tbi)
   }
   buffer_debug(&buffer);
 
-  XBT_DEBUG("%s: insert event_type=%d, timestamp=%f, buffersize=%zu)",
-      __FUNCTION__, (int)tbi->event_type, tbi->timestamp, buffer.size());
-  std::vector<PajeEvent*>::reverse_iterator i;
+  XBT_DEBUG("%s: insert event_type=%d, timestamp=%f, buffersize=%zu)", __FUNCTION__, (int)tbi->eventType_,
+            tbi->timestamp_, buffer.size());
+  std::vector<simgrid::instr::PajeEvent*>::reverse_iterator i;
   for (i = buffer.rbegin(); i != buffer.rend(); ++i) {
-    PajeEvent* e1 = *i;
-    XBT_DEBUG("compare to %p is of type %d; timestamp:%f", e1,
-        (int)e1->event_type, e1->timestamp);
-    if (e1->timestamp <= tbi->timestamp)
+    simgrid::instr::PajeEvent* e1 = *i;
+    XBT_DEBUG("compare to %p is of type %d; timestamp:%f", e1, (int)e1->eventType_, e1->timestamp_);
+    if (e1->timestamp_ <= tbi->timestamp_)
       break;
   }
   if (i == buffer.rend())
@@ -156,24 +151,9 @@ static void insert_into_buffer (PajeEvent* tbi)
   buffer_debug(&buffer);
 }
 
-PajeEvent:: ~PajeEvent()
+simgrid::instr::PajeEvent::~PajeEvent()
 {
-  XBT_DEBUG("%s not implemented for %p: event_type=%d, timestamp=%f", __FUNCTION__,
-      this, (int)event_type, timestamp);
-//  xbt_backtrace_display_current();
-
- /* switch (event->event_type){
-  case PAJE_StartLink:
-    xbt_free (((startLink_t)(event->data))->value);
-    xbt_free (((startLink_t)(event->data))->key);
-    break;
-  case PAJE_EndLink:
-    xbt_free (((endLink_t)(event->data))->value);
-    xbt_free (((endLink_t)(event->data))->key);
-    break;
-  default:
-    break;
-  }*/
+  XBT_DEBUG("%s not implemented for %p: event_type=%d, timestamp=%f", __FUNCTION__, this, (int)eventType_, timestamp_);
 }
 
 void TRACE_paje_start() {
@@ -212,15 +192,16 @@ void TRACE_paje_end() {
   XBT_DEBUG("Filename %s is closed", filename);
 }
 
-void DefineContainerEvent(type_t type)
+void LogContainerTypeDefinition(simgrid::instr::Type* type)
 {
-  XBT_DEBUG("%s: event_type=%d", __FUNCTION__, PAJE_DefineContainerType);
+  XBT_DEBUG("%s: event_type=%d", __FUNCTION__, simgrid::instr::PAJE_DefineContainerType);
   //print it
   if (instr_fmt_type == instr_fmt_paje) {
-    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, PAJE_DefineContainerType, TRACE_precision(), 0.);
+    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, simgrid::instr::PAJE_DefineContainerType,
+              TRACE_precision(), 0.);
     stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << PAJE_DefineContainerType;
-    stream << " " << type->id << " " << type->father->id << " " << type->name;
+    stream << simgrid::instr::PAJE_DefineContainerType;
+    stream << " " << type->id_ << " " << type->father_->id_ << " " << type->name_;
     print_row();
   } else if (instr_fmt_type == instr_fmt_TI) {
     /* Nothing to do */
@@ -230,22 +211,21 @@ void DefineContainerEvent(type_t type)
   //--
 }
 
-
-
-void LogVariableTypeDefinition(type_t type)
+void LogVariableTypeDefinition(simgrid::instr::Type* type)
 {
 
-  XBT_DEBUG("%s: event_type=%d", __FUNCTION__, PAJE_DefineVariableType);
+  XBT_DEBUG("%s: event_type=%d", __FUNCTION__, simgrid::instr::PAJE_DefineVariableType);
 
   //print it
 if (instr_fmt_type == instr_fmt_paje) {
-    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, PAJE_DefineVariableType, TRACE_precision(), 0.);
-    stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << PAJE_DefineVariableType;
-    stream << " " << type->id << " " << type->father->id << " " << type->name;
-    if (type->color)
-      stream << " \"" << type->color << "\"";
-    print_row();
+  XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, simgrid::instr::PAJE_DefineVariableType,
+            TRACE_precision(), 0.);
+  stream << std::fixed << std::setprecision(TRACE_precision());
+  stream << simgrid::instr::PAJE_DefineVariableType;
+  stream << " " << type->id_ << " " << type->father_->id_ << " " << type->name_;
+  if (type->color_)
+    stream << " \"" << type->color_ << "\"";
+  print_row();
   } else if (instr_fmt_type == instr_fmt_TI) {
     /* Nothing to do */
   } else {
@@ -253,16 +233,16 @@ if (instr_fmt_type == instr_fmt_paje) {
   }
 }
 
-
-void LogStateTypeDefinition(type_t type)
+void LogStateTypeDefinition(simgrid::instr::Type* type)
 {
   //print it
 if (instr_fmt_type == instr_fmt_paje) {
-    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, PAJE_DefineStateType, TRACE_precision(), 0.);
-    stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << PAJE_DefineStateType;
-    stream << " " << type->id << " " << type->father->id << " " << type->name;
-    print_row();
+  XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, simgrid::instr::PAJE_DefineStateType, TRACE_precision(),
+            0.);
+  stream << std::fixed << std::setprecision(TRACE_precision());
+  stream << simgrid::instr::PAJE_DefineStateType;
+  stream << " " << type->id_ << " " << type->father_->id_ << " " << type->name_;
+  print_row();
   } else if (instr_fmt_type == instr_fmt_TI) {
     /* Nothing to do */
   } else {
@@ -270,15 +250,15 @@ if (instr_fmt_type == instr_fmt_paje) {
   }
 }
 
-
-void LogDefineEventType(type_t type)
+void LogDefineEventType(simgrid::instr::Type* type)
 {
   //print it
   if (instr_fmt_type == instr_fmt_paje) {
-    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, PAJE_DefineEventType, TRACE_precision(), 0.);
+    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, simgrid::instr::PAJE_DefineEventType,
+              TRACE_precision(), 0.);
     stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << PAJE_DefineEventType;
-    stream << " " << type->id << " " << type->father->id << " " << type->name;
+    stream << simgrid::instr::PAJE_DefineEventType;
+    stream << " " << type->id_ << " " << type->father_->id_ << " " << type->name_;
     print_row();
   } else if (instr_fmt_type == instr_fmt_TI) {
     /* Nothing to do */
@@ -287,16 +267,18 @@ void LogDefineEventType(type_t type)
   }
 }
 
-void LogLinkTypeDefinition(type_t type, type_t source, type_t dest)
+void LogLinkTypeDefinition(simgrid::instr::Type* type, simgrid::instr::Type* source, simgrid::instr::Type* dest)
 {
-  XBT_DEBUG("%s: event_type=%d", __FUNCTION__, PAJE_DefineLinkType);
+  XBT_DEBUG("%s: event_type=%d", __FUNCTION__, simgrid::instr::PAJE_DefineLinkType);
   //print it
 if (instr_fmt_type == instr_fmt_paje) {
-    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, PAJE_DefineLinkType, TRACE_precision(), 0.);
-    stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << PAJE_DefineLinkType;
-    stream << " " << type->id << " " << type->father->id << " " << source->id << " " << dest->id << " " << type->name;
-    print_row();
+  XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, simgrid::instr::PAJE_DefineLinkType, TRACE_precision(),
+            0.);
+  stream << std::fixed << std::setprecision(TRACE_precision());
+  stream << simgrid::instr::PAJE_DefineLinkType;
+  stream << " " << type->id_ << " " << type->father_->id_ << " " << source->id_ << " " << dest->id_ << " "
+         << type->name_;
+  print_row();
   } else if (instr_fmt_type == instr_fmt_TI) {
     /* Nothing to do */
   } else {
@@ -304,16 +286,16 @@ if (instr_fmt_type == instr_fmt_paje) {
   }
 }
 
-void LogEntityValue (val_t value)
+void LogEntityValue(simgrid::instr::Value* val)
 {
-  XBT_DEBUG("%s: event_type=%d", __FUNCTION__, PAJE_DefineEntityValue);
+  XBT_DEBUG("%s: event_type=%d", __FUNCTION__, simgrid::instr::PAJE_DefineEntityValue);
   //print it
 if (instr_fmt_type == instr_fmt_paje) {
     stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << PAJE_DefineEntityValue;
-    stream << " " << value->id << " " << value->father->id << " " << value->name;
-    if (value->color)
-      stream << " \"" << value->color << "\"";
+    stream << simgrid::instr::PAJE_DefineEntityValue;
+    stream << " " << val->id_ << " " << val->father_->id_ << " " << val->name_;
+    if (val->color_)
+      stream << " \"" << val->color_ << "\"";
     print_row();
   } else if (instr_fmt_type == instr_fmt_TI) {
     /* Nothing to do */
@@ -325,21 +307,21 @@ if (instr_fmt_type == instr_fmt_paje) {
 
 void LogContainerCreation (container_t container)
 {
-  double timestamp                              = SIMIX_get_clock();
+  double timestamp = SIMIX_get_clock();
 
-  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, PAJE_CreateContainer,timestamp);
+  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, simgrid::instr::PAJE_CreateContainer, timestamp);
 
-if (instr_fmt_type == instr_fmt_paje) {
+  if (instr_fmt_type == instr_fmt_paje) {
     stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << PAJE_CreateContainer;
+    stream << simgrid::instr::PAJE_CreateContainer;
     stream << " ";
   /* prevent 0.0000 in the trace - this was the behavior before the transition to c++ */
     if (timestamp < 1e-12)
       stream << 0;
     else
       stream << timestamp;
-    stream << " " << container->id << " " << container->type->id << " " << container->father->id << " \""
-           << container->name << "\"";
+    stream << " " << container->id_ << " " << container->type_->id_ << " " << container->father_->id_ << " \""
+           << container->name_ << "\"";
 
     print_row();
   } else if (instr_fmt_type == instr_fmt_TI) {
@@ -354,7 +336,7 @@ if (instr_fmt_type == instr_fmt_paje) {
 
     if (not xbt_cfg_get_boolean("tracing/smpi/format/ti-one-file") || ti_unique_file == nullptr) {
       char* folder_name = bprintf("%s_files", TRACE_get_filename());
-      char* filename    = bprintf("%s/%f_%s.txt", folder_name, prefix, container->name);
+      char* filename    = bprintf("%s/%f_%s.txt", folder_name, prefix, container->name_);
 #ifdef WIN32
       _mkdir(folder_name);
 #else
@@ -368,7 +350,7 @@ if (instr_fmt_type == instr_fmt_paje) {
       xbt_free(filename);
     }
 
-    xbt_dict_set(tracing_files, container->name, (void*)ti_unique_file, nullptr);
+    xbt_dict_set(tracing_files, container->name_, (void*)ti_unique_file, nullptr);
   } else {
     THROW_IMPOSSIBLE;
   }
@@ -378,51 +360,51 @@ void LogContainerDestruction(container_t container)
 {
   double timestamp                               = SIMIX_get_clock();
 
-  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, PAJE_DestroyContainer, timestamp);
+  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, simgrid::instr::PAJE_DestroyContainer, timestamp);
 
-if (instr_fmt_type == instr_fmt_paje) {
+  if (instr_fmt_type == instr_fmt_paje) {
     stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << PAJE_DestroyContainer;
+    stream << simgrid::instr::PAJE_DestroyContainer;
     stream << " ";
   /* prevent 0.0000 in the trace - this was the behavior before the transition to c++ */
     if (timestamp < 1e-12)
         stream << 0;
-    else 
-        stream << timestamp;
-    stream << " " << container->type->id << " " << container->id;
+    else
+      stream << timestamp;
+    stream << " " << container->type_->id_ << " " << container->id_;
     print_row();
   } else if (instr_fmt_type == instr_fmt_TI) {
     if (not xbt_cfg_get_boolean("tracing/smpi/format/ti-one-file") || xbt_dict_length(tracing_files) == 1) {
-      FILE* f = (FILE*)xbt_dict_get_or_null(tracing_files, container->name);
+      FILE* f = (FILE*)xbt_dict_get_or_null(tracing_files, container->name_);
       fclose(f);
     }
-    xbt_dict_remove(tracing_files, container->name);
+    xbt_dict_remove(tracing_files, container->name_);
         } else {
           THROW_IMPOSSIBLE;
         }
 }
 
-
-SetVariableEvent::SetVariableEvent (double timestamp, container_t container, type_t type, double value)
+simgrid::instr::SetVariableEvent::SetVariableEvent(double timestamp, container_t container, Type* type, double value)
 {
-  this->event_type                         = PAJE_SetVariable;
-  this->timestamp                          = timestamp;
+  this->eventType_ = PAJE_SetVariable;
+  this->timestamp_ = timestamp;
   this->type      = type;
   this->container = container;
   this->value     = value;
 
-  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)event_type, this->timestamp);
+  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)eventType_, this->timestamp_);
 
   insert_into_buffer (this);
 }
 
-void SetVariableEvent::print() {
+void simgrid::instr::SetVariableEvent::print()
+{
   if (instr_fmt_type == instr_fmt_paje) {
-    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)event_type, TRACE_precision(), timestamp);
+    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)eventType_, TRACE_precision(), timestamp_);
     stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << (int)this->event_type;
+    stream << (int)this->eventType_;
     print_timestamp(this);
-    stream << " " << type->id << " " << container->id << " " << value;
+    stream << " " << type->id_ << " " << container->id_ << " " << value;
     print_row();
   } else if (instr_fmt_type == instr_fmt_TI) {
     /* Nothing to do */
@@ -431,26 +413,28 @@ void SetVariableEvent::print() {
   }
 }
 
-AddVariableEvent::AddVariableEvent (double timestamp, container_t container, type_t type, double value)
+simgrid::instr::AddVariableEvent::AddVariableEvent(double timestamp, container_t container, simgrid::instr::Type* type,
+                                                   double value)
 {
-  this->event_type                         = PAJE_AddVariable;
-  this->timestamp                          = timestamp;
+  this->eventType_ = PAJE_AddVariable;
+  this->timestamp_ = timestamp;
   this->type      = type;
   this->container = container;
   this->value     = value;
 
-  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)event_type, this->timestamp);
+  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)eventType_, this->timestamp_);
 
   insert_into_buffer (this);
 }
 
-void AddVariableEvent::print() {
+void simgrid::instr::AddVariableEvent::print()
+{
   if (instr_fmt_type == instr_fmt_paje) {
-    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)event_type, TRACE_precision(), timestamp);
+    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)eventType_, TRACE_precision(), timestamp_);
     stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << (int)this->event_type;
+    stream << (int)this->eventType_;
     print_timestamp(this);
-    stream << " " << type->id << " " << container->id << " " << value;
+    stream << " " << type->id_ << " " << container->id_ << " " << value;
     print_row();
   } else if (instr_fmt_type == instr_fmt_TI) {
     /* Nothing to do */
@@ -459,26 +443,27 @@ void AddVariableEvent::print() {
   }
 }
 
-SubVariableEvent::SubVariableEvent (double timestamp, container_t container, type_t type, double value)
+simgrid::instr::SubVariableEvent::SubVariableEvent(double timestamp, container_t container, Type* type, double value)
 {
-  this->event_type                         = PAJE_SubVariable;
-  this->timestamp                          = timestamp;
+  this->eventType_ = PAJE_SubVariable;
+  this->timestamp_ = timestamp;
   this->type      = type;
   this->container = container;
   this->value     = value;
 
-  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)event_type, this->timestamp);
+  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)eventType_, this->timestamp_);
 
   insert_into_buffer (this);
 }
 
-void SubVariableEvent::print() {
+void simgrid::instr::SubVariableEvent::print()
+{
   if (instr_fmt_type == instr_fmt_paje) {
-    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)event_type, TRACE_precision(), timestamp);
+    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)eventType_, TRACE_precision(), timestamp_);
     stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << (int)this->event_type;
+    stream << (int)this->eventType_;
     print_timestamp(this);
-    stream << " " << type->id << " " << container->id << " " << value;
+    stream << " " << type->id_ << " " << container->id_ << " " << value;
     print_row();
   } else if (instr_fmt_type == instr_fmt_TI) {
     /* Nothing to do */
@@ -487,13 +472,13 @@ void SubVariableEvent::print() {
   }
 }
 
-SetStateEvent::SetStateEvent (double timestamp, container_t container, type_t type, val_t value)
+simgrid::instr::SetStateEvent::SetStateEvent(double timestamp, container_t container, Type* type, Value* val)
 {
-  this->event_type                      = PAJE_SetState;
-  this->timestamp                       = timestamp;
+  this->eventType_                      = PAJE_SetState;
+  this->timestamp_                      = timestamp;
   this->type      = type;
   this->container = container;
-  this->value     = value;
+  this->val                             = val;
 
 #if HAVE_SMPI
   if (xbt_cfg_get_boolean("smpi/trace-call-location")) {
@@ -503,19 +488,20 @@ SetStateEvent::SetStateEvent (double timestamp, container_t container, type_t ty
   }
 #endif
 
-  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)event_type, this->timestamp);
+  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)eventType_, this->timestamp_);
 
   insert_into_buffer (this);
 }
 
-void SetStateEvent::print() {
+void simgrid::instr::SetStateEvent::print()
+{
   if (instr_fmt_type == instr_fmt_paje) {
-    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)event_type, TRACE_precision(), timestamp);
+    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)eventType_, TRACE_precision(), timestamp_);
     stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << (int)this->event_type;
+    stream << (int)this->eventType_;
     print_timestamp(this);
-    stream << " " << type->id << " " << container->id;
-    stream << " " << value->id;
+    stream << " " << type->id_ << " " << container->id_;
+    stream << " " << val->id_;
 #if HAVE_SMPI
     if (xbt_cfg_get_boolean("smpi/trace-call-location")) {
       stream << " \"" << filename << "\" " << linenumber;
@@ -529,13 +515,14 @@ void SetStateEvent::print() {
   }
 }
 
-PushStateEvent::PushStateEvent (double timestamp, container_t container, type_t type, val_t value, void* extra)
+simgrid::instr::PushStateEvent::PushStateEvent(double timestamp, container_t container, Type* type, Value* val,
+                                               void* extra)
 {
-  this->event_type                  = PAJE_PushState;
-  this->timestamp                   = timestamp;
+  this->eventType_                  = PAJE_PushState;
+  this->timestamp_                  = timestamp;
   this->type = type;
   this->container = container;
-  this->value     = value;
+  this->val                         = val;
   this->extra_     = extra;
 
 #if HAVE_SMPI
@@ -546,22 +533,23 @@ PushStateEvent::PushStateEvent (double timestamp, container_t container, type_t
   }
 #endif
 
-  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)event_type, this->timestamp);
+  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)eventType_, this->timestamp_);
 
   insert_into_buffer (this);
 }
 
-PushStateEvent::PushStateEvent (double timestamp, container_t container, type_t type, val_t value)
- : PushStateEvent(timestamp, container, type, value, nullptr)
+simgrid::instr::PushStateEvent::PushStateEvent(double timestamp, container_t container, Type* type, Value* val)
+    : PushStateEvent(timestamp, container, type, val, nullptr)
 {}
-void PushStateEvent::print() {
+void simgrid::instr::PushStateEvent::print()
+{
   if (instr_fmt_type == instr_fmt_paje) {
-    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)event_type, TRACE_precision(), timestamp);
+    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)eventType_, TRACE_precision(), timestamp_);
     stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << (int)this->event_type;
+    stream << (int)this->eventType_;
     print_timestamp(this);
-    stream << " " << type->id << " " << container->id;
-    stream << " " << value->id;
+    stream << " " << type->id_ << " " << container->id_;
+    stream << " " << val->id_;
 
     if (TRACE_display_sizes()) {
       stream << " ";
@@ -592,12 +580,12 @@ void PushStateEvent::print() {
 
     char* process_id = nullptr;
     // FIXME: dirty extract "rank-" from the name, as we want the bare process id here
-    if (strstr(container->name, "rank-") == nullptr)
-      process_id = xbt_strdup(container->name);
+    if (strstr(container->name_, "rank-") == nullptr)
+      process_id = xbt_strdup(container->name_);
     else
-      process_id = xbt_strdup(container->name + 5);
+      process_id = xbt_strdup(container->name_ + 5);
 
-    FILE* trace_file = (FILE*)xbt_dict_get(tracing_files, container->name);
+    FILE* trace_file = (FILE*)xbt_dict_get(tracing_files, container->name_);
 
     switch (extra->type) {
       case TRACING_INIT:
@@ -687,11 +675,13 @@ void PushStateEvent::print() {
           fprintf(trace_file, "%d ", extra->recvcounts[i]);
         fprintf(trace_file, "%d %s %s\n", extra->root, extra->datatype1, extra->datatype2);
         break;
+      case TRACING_ALLGATHER: // rank allgather sendcount recvcounts (sendtype) (recvtype)
+        fprintf(trace_file, "%s allGather %d %d %s %s", process_id, extra->send_size, extra->recv_size, extra->datatype1, extra->datatype2);
+        break;
       case TRACING_WAITANY:
       case TRACING_SENDRECV:
       case TRACING_SCATTER:
       case TRACING_SCATTERV:
-      case TRACING_ALLGATHER:
       case TRACING_SCAN:
       case TRACING_EXSCAN:
       case TRACING_COMM_SIZE:
@@ -700,7 +690,7 @@ void PushStateEvent::print() {
       case TRACING_SSEND:
       case TRACING_ISSEND:
       default:
-        XBT_WARN("Call from %s impossible to translate into replay command : Not implemented (yet)", value->name);
+        XBT_WARN("Call from %s impossible to translate into replay command : Not implemented (yet)", val->name_);
         break;
     }
 
@@ -716,26 +706,26 @@ void PushStateEvent::print() {
   }
 }
 
-
-PopStateEvent::PopStateEvent (double timestamp, container_t container, type_t type)
+simgrid::instr::PopStateEvent::PopStateEvent(double timestamp, container_t container, Type* type)
 {
-  this->event_type                      = PAJE_PopState;
-  this->timestamp                       = timestamp;
+  this->eventType_ = PAJE_PopState;
+  this->timestamp_ = timestamp;
   this->type      = type;
   this->container = container;
 
-  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)event_type, this->timestamp);
+  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)eventType_, this->timestamp_);
 
   insert_into_buffer (this);
 }
 
-void PopStateEvent::print() {
+void simgrid::instr::PopStateEvent::print()
+{
   if (instr_fmt_type == instr_fmt_paje) {
-    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)event_type, TRACE_precision(), timestamp);
+    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)eventType_, TRACE_precision(), timestamp_);
     stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << (int)this->event_type;
+    stream << (int)this->eventType_;
     print_timestamp(this);
-    stream << " " << type->id << " " << container->id;
+    stream << " " << type->id_ << " " << container->id_;
     print_row();
   } else if (instr_fmt_type == instr_fmt_TI) {
     /* Nothing to do */
@@ -744,26 +734,27 @@ void PopStateEvent::print() {
   }
 }
 
-ResetStateEvent::ResetStateEvent (double timestamp, container_t container, type_t type)
+simgrid::instr::ResetStateEvent::ResetStateEvent(double timestamp, container_t container, Type* type)
 {
-  this->event_type                        = PAJE_ResetState;
-  this->timestamp                         = timestamp;
+  this->eventType_ = PAJE_ResetState;
+  this->timestamp_ = timestamp;
   this->type      = type;
   this->container = container;
 
-  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)event_type, this->timestamp);
+  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)eventType_, this->timestamp_);
 
   insert_into_buffer (this);
   delete[] this;
 }
 
-void ResetStateEvent::print() {
+void simgrid::instr::ResetStateEvent::print()
+{
   if (instr_fmt_type == instr_fmt_paje) {
-    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)event_type, TRACE_precision(), timestamp);
+    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)eventType_, TRACE_precision(), timestamp_);
     stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << (int)this->event_type;
+    stream << (int)this->eventType_;
     print_timestamp(this);
-    stream << " " << type->id << " " << container->id;
+    stream << " " << type->id_ << " " << container->id_;
     print_row();
   } else if (instr_fmt_type == instr_fmt_TI) {
     /* Nothing to do */
@@ -772,45 +763,41 @@ void ResetStateEvent::print() {
   }
 }
 
-StartLinkEvent::~StartLinkEvent()
-{
-  free(value);
-  free(key);
-}
-StartLinkEvent::StartLinkEvent (double timestamp, container_t container,
-    type_t type, container_t sourceContainer, const char *value, const char *key)
-  : StartLinkEvent(timestamp, container, type, sourceContainer, value, key, -1)
+simgrid::instr::StartLinkEvent::StartLinkEvent(double timestamp, container_t container, Type* type,
+                                               container_t sourceContainer, const char* value, const char* key)
+    : StartLinkEvent(timestamp, container, type, sourceContainer, value, key, -1)
 {}
 
-StartLinkEvent::StartLinkEvent (double timestamp, container_t container, type_t type, container_t sourceContainer,
-                                const char *value, const char *key, int size)
+simgrid::instr::StartLinkEvent::StartLinkEvent(double timestamp, container_t container, Type* type,
+                                               container_t sourceContainer, const char* value, const char* key,
+                                               int size)
+    : container_(container)
+    , type_(type)
+    , sourceContainer_(sourceContainer)
+    , value_(value)
+    , key_(key)
+    , size_(size)
 {
-  event_type                             = PAJE_StartLink;
-  this->timestamp       = timestamp;
-  this->type            = type;
-  this->container       = container;
-  this->sourceContainer = sourceContainer;
-  this->value           = xbt_strdup(value);
-  this->key             = xbt_strdup(key);
-  this->size            = size;
+  eventType_            = PAJE_StartLink;
+  this->timestamp_      = timestamp;
 
-  XBT_DEBUG("%s: event_type=%d, timestamp=%f, value:%s", __FUNCTION__,
-      (int)event_type, this->timestamp, this->value);
+  XBT_DEBUG("%s: event_type=%d, timestamp=%f, value:%s", __FUNCTION__, (int)eventType_, this->timestamp_, this->value_.c_str());
 
   insert_into_buffer (this);
 }
 
-void StartLinkEvent::print() {
+void simgrid::instr::StartLinkEvent::print()
+{
   if (instr_fmt_type == instr_fmt_paje) {
-    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)event_type, TRACE_precision(), timestamp);
+    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)eventType_, TRACE_precision(), timestamp_);
     stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << (int)this->event_type;
+    stream << (int)this->eventType_;
     print_timestamp(this);
-    stream << " " << type->id << " " << container->id << " " << value;
-    stream << " " << sourceContainer->id << " " << key;
+    stream << " " << type_->id_ << " " << container_->id_ << " " << value_;
+    stream << " " << sourceContainer_->id_ << " " << key_;
 
     if (TRACE_display_sizes()) {
-      stream << " " << size;
+      stream << " " << size_;
     }
     print_row();
   } else if (instr_fmt_type == instr_fmt_TI) {
@@ -820,35 +807,36 @@ void StartLinkEvent::print() {
   }
 }
 
-EndLinkEvent::EndLinkEvent (double timestamp, container_t container, type_t type, container_t destContainer,
-                      const char *value, const char *key)
+simgrid::instr::EndLinkEvent::EndLinkEvent(double timestamp, container_t container, Type* type,
+                                           container_t destContainer, const char* value, const char* key)
 {
-  this->event_type                         = PAJE_EndLink;
-  this->timestamp                          = timestamp;
+  this->eventType_    = PAJE_EndLink;
+  this->timestamp_    = timestamp;
   this->type          = type;
   this->container     = container;
   this->destContainer = destContainer;
   this->value         = xbt_strdup(value);
   this->key           = xbt_strdup(key);
 
-  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)event_type, this->timestamp);
+  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)eventType_, this->timestamp_);
 
   insert_into_buffer (this);
 }
 
-EndLinkEvent::~EndLinkEvent()
+simgrid::instr::EndLinkEvent::~EndLinkEvent()
 {
   free(value);
   free(key);
 }
-void EndLinkEvent::print() {
+void simgrid::instr::EndLinkEvent::print()
+{
   if (instr_fmt_type == instr_fmt_paje) {
-    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)event_type, TRACE_precision(), timestamp);
+    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)eventType_, TRACE_precision(), timestamp_);
     stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << (int)this->event_type;
+    stream << (int)this->eventType_;
     print_timestamp(this);
-    stream << " " << type->id << " " << container->id << " " << value;
-    stream << " " << destContainer->id << " " << key;
+    stream << " " << type->id_ << " " << container->id_ << " " << value;
+    stream << " " << destContainer->id_ << " " << key;
     print_row();
   } else if (instr_fmt_type == instr_fmt_TI) {
     /* Nothing to do */
@@ -857,26 +845,27 @@ void EndLinkEvent::print() {
   }
 }
 
-NewEvent::NewEvent (double timestamp, container_t container, type_t type, val_t value)
+simgrid::instr::NewEvent::NewEvent(double timestamp, container_t container, Type* type, Value* val)
 {
-  this->event_type                      = PAJE_NewEvent;
-  this->timestamp                       = timestamp;
+  this->eventType_                      = PAJE_NewEvent;
+  this->timestamp_                      = timestamp;
   this->type      = type;
   this->container = container;
-  this->value     = value;
+  this->val                             = val;
 
-  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)event_type, this->timestamp);
+  XBT_DEBUG("%s: event_type=%d, timestamp=%f", __FUNCTION__, (int)eventType_, this->timestamp_);
 
   insert_into_buffer (this);
 }
 
-void NewEvent::print () {
+void simgrid::instr::NewEvent::print()
+{
   if (instr_fmt_type == instr_fmt_paje) {
-    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)event_type, TRACE_precision(), timestamp);
+    XBT_DEBUG("%s: event_type=%d, timestamp=%.*f", __FUNCTION__, (int)eventType_, TRACE_precision(), timestamp_);
     stream << std::fixed << std::setprecision(TRACE_precision());
-    stream << (int)this->event_type;
+    stream << (int)this->eventType_;
     print_timestamp(this);
-    stream << " " << type->id << " " << container->id << " " << value->id;
+    stream << " " << type->id_ << " " << container->id_ << " " << val->id_;
     print_row();
   } else if (instr_fmt_type == instr_fmt_TI) {
     /* Nothing to do */
