@@ -8,12 +8,12 @@
 
 #include <xbt/base.h>
 
-#include "simgrid/instr.h"
 #include "instr/instr_interface.h"
-#include "src/internal_config.h"
+#include "simgrid/instr.h"
 #include "simgrid_config.h"
-
-SG_BEGIN_DECL()
+#include "src/internal_config.h"
+#include <set>
+#include <string>
 
 /* Need to define function drand48 for Windows */
 /* FIXME: use _drand48() defined in src/surf/random_mgr.c instead */
@@ -26,6 +26,8 @@ SG_BEGIN_DECL()
 #include "xbt/graph.h"
 #include "xbt/dict.h"
 
+namespace simgrid {
+namespace instr {
 typedef enum {
   PAJE_DefineContainerType,
   PAJE_DefineVariableType,
@@ -56,33 +58,43 @@ typedef enum {
 } e_entity_types;
 
 //--------------------------------------------------
-class s_type;
-typedef s_type *type_t;
-class s_type {
-  public:
-  char *id;
-  char *name;
-  char *color;
-  e_entity_types kind;
-  s_type *father;
-  xbt_dict_t children;
-  xbt_dict_t values; //valid for all types except variable and container
-};
 
-typedef s_type s_type_t;
+class Type {
+public:
+  char* id_;
+  char* name_;
+  char* color_;
+
+  e_entity_types kind_;
+  Type* father_;
+  xbt_dict_t children_;
+  xbt_dict_t values_; // valid for all types except variable and container
+  Type(const char* typeNameBuff, const char* key, const char* color, e_entity_types kind, Type* father);
+  ~Type();
+  Type* getChild(const char* name);
+  Type* getChildOrNull(const char* name);
+
+  static Type* containerNew(const char* name, Type* father);
+  static Type* eventNew(const char* name, Type* father);
+  static Type* variableNew(const char* name, const char* color, Type* father);
+  static Type* linkNew(const char* name, Type* father, Type* source, Type* dest);
+  static Type* stateNew(const char* name, Type* father);
+};
 
 //--------------------------------------------------
-class s_val;
-typedef s_val *val_t;
+class Value {
+public:
+  char* id_;
+  char* name_;
+  char* color_;
 
-class s_val {
-  public:
-  char *id;
-  char *name;
-  char *color;
-  type_t father;
+  Type* father_;
+  Value(const char* name, const char* color, Type* father);
+  ~Value();
+  static Value* get_or_new(const char* name, const char* color, Type* father);
+  static Value* get(const char* name, Type* father);
 };
-typedef s_val s_val_t;
+
 
 //--------------------------------------------------
 typedef enum {
@@ -97,177 +109,167 @@ typedef enum {
 } e_container_types;
 
 //--------------------------------------------------
-class s_container;
-typedef s_container *container_t;
 
-class s_container {
-  public:
-  sg_netpoint_t netpoint;
-  char *name;     /* Unique name of this container */
-  char *id;       /* Unique id of this container */
-  type_t type;    /* Type of this container */
-  int level;      /* Level in the hierarchy, root level is 0 */
-  e_container_types kind; /* This container is of what kind */
-  s_container *father;
-  xbt_dict_t children;
+class Container {
+public:
+  Container(const char* name, simgrid::instr::e_container_types kind, Container* father);
+  virtual ~Container();
+
+  sg_netpoint_t netpoint_;
+  char* name_;             /* Unique name of this container */
+  char* id_;               /* Unique id of this container */
+  Type* type_;             /* Type of this container */
+  int level_ = 0;          /* Level in the hierarchy, root level is 0 */
+  e_container_types kind_; /* This container is of what kind */
+  Container* father_;
+  xbt_dict_t children_;
 };
-typedef s_container s_container_t;
 
 //--------------------------------------------------
 class PajeEvent {
   public:
-  double timestamp;
-  e_event_type event_type;
-  virtual void print() = 0;
-  void *data;
-  virtual ~PajeEvent();
+    double timestamp_;
+    e_event_type eventType_;
+    virtual void print() = 0;
+    virtual ~PajeEvent();
 };
 
 //--------------------------------------------------
-
-class DefineVariableTypeEvent : public PajeEvent
-{
-  public:
-  type_t type;
-   DefineVariableTypeEvent(type_t type);
-   void print() override;
-};
-//--------------------------------------------------
-
-class DefineStateTypeEvent : public PajeEvent  {
-  type_t type;
-  public:
-  DefineStateTypeEvent(type_t type);
-  void print() override;
-};
-
-
 class SetVariableEvent : public PajeEvent  {
-  container_t container;
-  type_t type;
-  double value;
-  public:
-  SetVariableEvent (double timestamp, container_t container, type_t type, double value);
-  void print() override;
-};
+  private:
+    Container* container;
+    Type* type;
+    double value;
 
+  public:
+    SetVariableEvent(double timestamp, Container* container, Type* type, double value);
+    void print() override;
+};
 
 class AddVariableEvent:public PajeEvent {
-  container_t container;
-  type_t type;
-  double value;
-  public:
-  AddVariableEvent (double timestamp, container_t container, type_t type, double value);
-  void print() override;
-};
+  private:
+    Container* container;
+    Type* type;
+    double value;
 
+  public:
+    AddVariableEvent(double timestamp, Container* container, Type* type, double value);
+    void print() override;
+};
 //--------------------------------------------------
 
 
 class SubVariableEvent : public PajeEvent  {
+  private:
+    Container* container;
+    Type* type;
+    double value;
+
   public:
-  container_t container;
-  type_t type;
-  double value;
-  public:
-  SubVariableEvent(double timestamp, container_t container, type_t type, double value);
-  void print() override;
+    SubVariableEvent(double timestamp, Container* container, Type* type, double value);
+    void print() override;
 };
 //--------------------------------------------------
 
 class SetStateEvent : public PajeEvent  {
+  private:
+    Container* container;
+    Type* type;
+    Value* val;
+    const char* filename;
+    int linenumber;
+
   public:
-  container_t container;
-  type_t type;
-  val_t value;
-  const char* filename;
-  int linenumber;
-  public:
-  SetStateEvent (double timestamp, container_t container, type_t type, val_t value);
-  void print() override;
+    SetStateEvent(double timestamp, Container* container, Type* type, Value* val);
+    void print() override;
 };
 
 
 class PushStateEvent : public PajeEvent  {
   public:
-  container_t container;
-  type_t type;
-  val_t value;
-  int size;
-  const char* filename;
-  int linenumber;
-  void* extra_;
+    Container* container;
+    Type* type;
+    Value* val;
+    int size;
+    const char* filename;
+    int linenumber;
+    void* extra_;
+
   public:
-  PushStateEvent (double timestamp, container_t container, type_t type, val_t value);
-  PushStateEvent (double timestamp, container_t container, type_t type, val_t value,
-                                             void* extra);
-  void print() override;
+    PushStateEvent(double timestamp, Container* container, Type* type, Value* val);
+    PushStateEvent(double timestamp, Container* container, Type* type, Value* val, void* extra);
+    void print() override;
 };
 
 class PopStateEvent : public PajeEvent  {
-  container_t container;
-  type_t type;
-  public:
-  PopStateEvent (double timestamp, container_t container, type_t type);
+  Container* container;
+  Type* type;
+
+public:
+  PopStateEvent(double timestamp, Container* container, Type* type);
   void print() override;
 };
 
 class ResetStateEvent : public PajeEvent  {
-  container_t container;
-  type_t type;
-  public:
-  ResetStateEvent (double timestamp, container_t container, type_t type);
+  Container* container;
+  Type* type;
+
+public:
+  ResetStateEvent(double timestamp, Container* container, Type* type);
   void print() override;
 };
 
 class StartLinkEvent : public PajeEvent  {
-  public:
-  container_t container;
-  type_t type;
-  container_t sourceContainer;
-  char *value;
-  char *key;
-  int size;
-  public:
-    ~StartLinkEvent();
-    StartLinkEvent(double timestamp, container_t container, type_t type, container_t sourceContainer, const char* value,
-                   const char* key);
-    StartLinkEvent(double timestamp, container_t container, type_t type, container_t sourceContainer, const char* value,
-                   const char* key, int size);
-    void print() override;
+  Container* container_;
+  Type* type_;
+  Container* sourceContainer_;
+  std::string value_;
+  std::string key_;
+  int size_;
+
+public:
+  StartLinkEvent(double timestamp, Container* container, Type* type, Container* sourceContainer, const char* value,
+                 const char* key);
+  StartLinkEvent(double timestamp, Container* container, Type* type, Container* sourceContainer, const char* value,
+                 const char* key, int size);
+  void print() override;
 };
 
 class EndLinkEvent : public PajeEvent  {
-  container_t container;
-  type_t type;
-  container_t destContainer;
+  Container* container;
+  Type* type;
+  Container* destContainer;
   char *value;
   char *key;
   public:
-  EndLinkEvent (double timestamp, container_t container, type_t type, container_t destContainer,
-                                  const char *value, const char *key);
-  ~EndLinkEvent();
-  void print() override;
+    EndLinkEvent(double timestamp, Container* container, Type* type, Container* destContainer, const char* value,
+                 const char* key);
+    ~EndLinkEvent();
+    void print() override;
 };
 
 
 class NewEvent : public PajeEvent  {
   public:
-  container_t container;
-  type_t type;
-  val_t value;
+    Container* container;
+    Type* type;
+    Value* val;
+
   public:
-  NewEvent (double timestamp, container_t container, type_t type, val_t value);
-  void print() override;
-
+    NewEvent(double timestamp, Container* container, Type* type, Value* val);
+    void print() override;
 };
+}
+} // namespace simgrid::instr
+typedef simgrid::instr::Container* container_t;
 
+SG_BEGIN_DECL()
 
-extern XBT_PRIVATE xbt_dict_t created_categories;
-extern XBT_PRIVATE xbt_dict_t declared_marks;
-extern XBT_PRIVATE xbt_dict_t user_host_variables;
-extern XBT_PRIVATE xbt_dict_t user_vm_variables;
-extern XBT_PRIVATE xbt_dict_t user_link_variables;
+extern XBT_PRIVATE std::set<std::string> created_categories;
+extern XBT_PRIVATE std::set<std::string> declared_marks;
+extern XBT_PRIVATE std::set<std::string> user_host_variables;
+extern XBT_PRIVATE std::set<std::string> user_vm_variables;
+extern XBT_PRIVATE std::set<std::string> user_link_variables;
 extern XBT_PRIVATE double TRACE_last_timestamp_to_dump;
 
 /* instr_paje_header.c */
@@ -322,44 +324,23 @@ XBT_PRIVATE void TRACE_surf_link_set_utilization(const char *resource,const char
 XBT_PUBLIC(void) TRACE_surf_resource_utilization_alloc();
 
 /* instr_paje.c */
-extern XBT_PRIVATE xbt_dict_t trivaNodeTypes;
-extern XBT_PRIVATE xbt_dict_t trivaEdgeTypes;
+extern XBT_PRIVATE std::set<std::string> trivaNodeTypes;
+extern XBT_PRIVATE std::set<std::string> trivaEdgeTypes;
 XBT_PRIVATE long long int instr_new_paje_id ();
-XBT_PRIVATE void PJ_container_alloc ();
-XBT_PRIVATE void PJ_container_release ();
-XBT_PUBLIC(container_t) PJ_container_new (const char *name, e_container_types kind, container_t father);
 XBT_PUBLIC(container_t) PJ_container_get (const char *name);
-XBT_PUBLIC(container_t) PJ_container_get_or_null (const char *name);
+XBT_PUBLIC(simgrid::instr::Container*) PJ_container_get_or_null(const char* name);
 XBT_PUBLIC(container_t) PJ_container_get_root ();
 XBT_PUBLIC(void) PJ_container_set_root (container_t root);
-XBT_PUBLIC(void) PJ_container_free (container_t container);
 XBT_PUBLIC(void) PJ_container_free_all (void);
 XBT_PUBLIC(void) PJ_container_remove_from_parent (container_t container);
 
 /* instr_paje_types.c */
-XBT_PRIVATE void PJ_type_alloc ();
-XBT_PRIVATE void PJ_type_release ();
-XBT_PUBLIC(type_t)  PJ_type_get_root ();
-XBT_PRIVATE type_t PJ_type_container_new (const char *name, type_t father);
-XBT_PRIVATE type_t PJ_type_event_new (const char *name, type_t father);
-type_t PJ_type_link_new (const char *name, type_t father, type_t source, type_t dest);
-XBT_PRIVATE XBT_PRIVATE type_t PJ_type_variable_new (const char *name, const char *color, type_t father);
-XBT_PRIVATE type_t PJ_type_state_new (const char *name, type_t father);
-XBT_PUBLIC(type_t)  PJ_type_get (const char *name, const type_t father);
-XBT_PUBLIC(type_t)  PJ_type_get_or_null (const char *name, type_t father);
-void PJ_type_free_all ();
-XBT_PRIVATE XBT_PRIVATE void PJ_type_free (type_t type);
-
-/* instr_paje_values.c */
-XBT_PUBLIC(val_t)  PJ_value_new (const char *name, const char *color, type_t father);
-XBT_PUBLIC(val_t)  PJ_value_get_or_new (const char *name, const char *color, type_t father);
-XBT_PUBLIC(val_t)  PJ_value_get (const char *name, const type_t father);
-XBT_PRIVATE void PJ_value_free (val_t value);
+XBT_PUBLIC(simgrid::instr::Type*) PJ_type_get_root();
 
+/* instr_config.c */
 XBT_PRIVATE void TRACE_TI_start();
 XBT_PRIVATE void TRACE_TI_end();
 
-XBT_PRIVATE void print_NULL (PajeEvent* event);
 XBT_PRIVATE void TRACE_paje_dump_buffer (int force);
 XBT_PRIVATE void dump_comment_file (const char *filename);
 XBT_PRIVATE void dump_comment (const char *comment);
@@ -429,13 +410,13 @@ extern instr_fmt_type_t instr_fmt_type;
 
 SG_END_DECL()
 
-void DefineContainerEvent(type_t type);
-void LogVariableTypeDefinition(type_t type);
-void LogStateTypeDefinition(type_t type);
-void LogLinkTypeDefinition(type_t type, type_t source, type_t dest);
-void LogEntityValue (val_t value);
+void LogContainerTypeDefinition(simgrid::instr::Type* type);
+void LogVariableTypeDefinition(simgrid::instr::Type* type);
+void LogStateTypeDefinition(simgrid::instr::Type* type);
+void LogLinkTypeDefinition(simgrid::instr::Type* type, simgrid::instr::Type* source, simgrid::instr::Type* dest);
+void LogEntityValue(simgrid::instr::Value* val);
 void LogContainerCreation (container_t container);
 void LogContainerDestruction (container_t container);
-void LogDefineEventType(type_t type);
+void LogDefineEventType(simgrid::instr::Type* type);
 
 #endif
