@@ -23,12 +23,6 @@ XBT_PRIVATE std::string request_to_string(smx_simcall_t req, int value, simgrid:
 
 XBT_PRIVATE bool request_is_enabled_by_idx(smx_simcall_t req, unsigned int idx);
 
-/** Is the process ready to execute its simcall?
- *
- *  This is true if the request associated with the process is ready.
- */
-XBT_PRIVATE bool actor_is_enabled(smx_actor_t process);
-
 XBT_PRIVATE std::string request_get_dot_output(smx_simcall_t req, int value);
 
 }
