@@ -1,5 +1,4 @@
-/* Copyright (c) 2007-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2007-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -7,16 +6,7 @@
 #ifndef SIMGRID_MC_SAFETY_H
 #define SIMGRID_MC_SAFETY_H
 
-#include <stdint.h>
-
-#include <memory>
-
-#include <simgrid_config.h>
-
-#include <xbt/base.h>
-
-#include "src/mc/mc_forward.hpp"
-#include "src/mc/mc_state.h"
+#include "xbt/base.h"
 
 namespace simgrid {
 namespace mc {
