@@ -1,4 +1,4 @@
-/* Copyright (c) 2009-2010, 2012-2015. The SimGrid Team.
+/* Copyright (c) 2009-2010, 2012-2017. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -11,7 +11,6 @@
 #include "xbt/config.hpp"
 #include "xbt/log.h"
 #include "xbt/mallocator.h"
-#include "xbt/str.h"
 #include "xbt/sysdep.h"
 #include "surf/surf.h"
 #include "surf/maxmin.h"
@@ -341,22 +340,16 @@ void sg_config_init(int *argc, char **argv)
 
   /* The parameters of network models */
 
-  // real default for "network/sender-gap" is set in network_smpi.cpp:
-  sg_sender_gap = NAN;
-  simgrid::config::bindFlag(sg_sender_gap, {"network/sender-gap", "network/sender_gap"},
-                            "Minimum gap between two overlapping sends");
-
-  sg_latency_factor = 1.0;
+  sg_latency_factor = 13.01; // comes from the default LV08 network model
   simgrid::config::bindFlag(sg_latency_factor, {"network/latency-factor", "network/latency_factor"},
                             "Correction factor to apply to the provided latency (default value set by network model)");
 
-  sg_bandwidth_factor = 1.0;
+  sg_bandwidth_factor = 0.97; // comes from the default LV08 network model
   simgrid::config::bindFlag(
       sg_bandwidth_factor, {"network/bandwidth-factor", "network/bandwidth_factor"},
       "Correction factor to apply to the provided bandwidth (default value set by network model)");
 
-  // real default for "network/weight-S" is set in network_*.cpp:
-  sg_weight_S_parameter = NAN;
+  sg_weight_S_parameter = 20537; // comes from the default LV08 network model
   simgrid::config::bindFlag(
       sg_weight_S_parameter, {"network/weight-S", "network/weight_S"},
       "Correction factor to apply to the weight of competing streams (default value set by network model)");
@@ -392,8 +385,8 @@ void sg_config_init(int *argc, char **argv)
     xbt_cfg_register_boolean("model-check/sparse-checkpoint", "no", _mc_cfg_cb_sparse_checkpoint, "Use sparse per-page snapshots.");
     xbt_cfg_register_boolean("model-check/ksm", "no", _mc_cfg_cb_ksm, "Kernel same-page merging");
 
-    xbt_cfg_register_string("model-check/property","", _mc_cfg_cb_property,
-        "Name of the file containing the property, as formated by the ltl2ba program.");
+    xbt_cfg_register_string("model-check/property", "", _mc_cfg_cb_property,
+                            "Name of the file containing the property, as formatted by the ltl2ba program.");
     xbt_cfg_register_boolean("model-check/communications-determinism", "no", _mc_cfg_cb_comms_determinism,
         "Whether to enable the detection of communication determinism");
     xbt_cfg_register_alias("model-check/communications-determinism","model-check/communications_determinism");
@@ -458,7 +451,7 @@ void sg_config_init(int *argc, char **argv)
     xbt_cfg_register_boolean("network/crosstraffic", "yes", _sg_cfg_cb__surf_network_crosstraffic,
         "Activate the interferences between uploads and downloads for fluid max-min models (LV08, CM02)");
 
-    //For smpi/bw_factor and smpi/lat_factor
+    // For smpi/bw-factor and smpi/lat-factor
     // SMPI model can be used without enable_smpi, so keep this out of the ifdef.
     xbt_cfg_register_string("smpi/bw-factor",
         "65472:0.940694;15424:0.697866;9376:0.58729;5776:1.08739;3484:0.77493;1426:0.608902;732:0.341987;257:0.338112;0:0.812084", nullptr,
