@@ -84,8 +84,7 @@ smx_activity_t simcall_execution_start(const char *name,
  * \return A new SIMIX execution synchronization
  */
 smx_activity_t simcall_execution_parallel_start(const char* name, int host_nb, sg_host_t* host_list,
-                                                double* flops_amount, double* bytes_amount, double amount, double rate,
-                                                double timeout)
+                                                double* flops_amount, double* bytes_amount, double rate, double timeout)
 {
   /* checking for infinite values */
   for (int i = 0 ; i < host_nb ; ++i) {
@@ -98,11 +97,9 @@ smx_activity_t simcall_execution_parallel_start(const char* name, int host_nb, s
     }
   }
 
-  xbt_assert(std::isfinite(amount), "amount is not finite!");
   xbt_assert(std::isfinite(rate), "rate is not finite!");
 
-  return simcall_BODY_execution_parallel_start(name, host_nb, host_list, flops_amount, bytes_amount, amount, rate,
-                                               timeout);
+  return simcall_BODY_execution_parallel_start(name, host_nb, host_list, flops_amount, bytes_amount, rate, timeout);
 }
 
 /**
@@ -114,7 +111,14 @@ smx_activity_t simcall_execution_parallel_start(const char* name, int host_nb, s
  */
 void simcall_execution_cancel(smx_activity_t execution)
 {
-  simcall_BODY_execution_cancel(execution);
+  simgrid::simix::kernelImmediate([execution] {
+    XBT_DEBUG("Cancel synchro %p", execution.get());
+    simgrid::kernel::activity::ExecImplPtr exec =
+        boost::static_pointer_cast<simgrid::kernel::activity::ExecImpl>(execution);
+
+    if (exec->surf_exec)
+      exec->surf_exec->cancel();
+  });
 }
 
 /**
@@ -129,8 +133,13 @@ void simcall_execution_set_priority(smx_activity_t execution, double priority)
 {
   /* checking for infinite values */
   xbt_assert(std::isfinite(priority), "priority is not finite!");
+  simgrid::simix::kernelImmediate([execution, priority] {
 
-  simcall_BODY_execution_set_priority(execution, priority);
+    simgrid::kernel::activity::ExecImplPtr exec =
+        boost::static_pointer_cast<simgrid::kernel::activity::ExecImpl>(execution);
+    if (exec->surf_exec)
+      exec->surf_exec->setSharingWeight(priority);
+  });
 }
 
 /**
@@ -143,7 +152,12 @@ void simcall_execution_set_priority(smx_activity_t execution, double priority)
  */
 void simcall_execution_set_bound(smx_activity_t execution, double bound)
 {
-  simcall_BODY_execution_set_bound(execution, bound);
+  simgrid::simix::kernelImmediate([execution, bound] {
+    simgrid::kernel::activity::ExecImplPtr exec =
+        boost::static_pointer_cast<simgrid::kernel::activity::ExecImpl>(execution);
+    if (exec->surf_exec)
+      static_cast<simgrid::surf::CpuAction*>(exec->surf_exec)->setBound(bound);
+  });
 }
 
 /**
@@ -157,19 +171,6 @@ e_smx_state_t simcall_execution_wait(smx_activity_t execution)
   return (e_smx_state_t) simcall_BODY_execution_wait(execution);
 }
 
-/**
- * \ingroup simix_process_management
- * \brief Kills a SIMIX process.
- *
- * This function simply kills a  process.
- *
- * \param process poor victim
- */
-void simcall_process_kill(smx_actor_t process)
-{
-  simcall_BODY_process_kill(process);
-}
-
 /**
  * \ingroup simix_process_management
  * \brief Kills all SIMIX processes.
@@ -189,20 +190,6 @@ void simcall_process_cleanup(smx_actor_t process)
   simcall_BODY_process_cleanup(process);
 }
 
-/**
- * \ingroup simix_process_management
- * \brief Migrates an agent to another location.
- *
- * This function changes the value of the host on which \a process is running.
- *
- * \param process the process to migrate
- * \param dest name of the new host
- */
-void simcall_process_set_host(smx_actor_t process, sg_host_t dest)
-{
-  simcall_BODY_process_set_host(process, dest);
-}
-
 void simcall_process_join(smx_actor_t process, double timeout)
 {
   simcall_BODY_process_join(process, timeout);
@@ -222,20 +209,6 @@ void simcall_process_suspend(smx_actor_t process)
   simcall_BODY_process_suspend(process);
 }
 
-/**
- * \ingroup simix_process_management
- * \brief Resumes a suspended process.
- *
- * This function resumes a suspended process by resuming the synchro
- * it was waiting for completion.
- *
- * \param process a SIMIX process
- */
-void simcall_process_resume(smx_actor_t process)
-{
-  simcall_BODY_process_resume(process);
-}
-
 /**
  * \ingroup simix_process_management
  * \brief Returns the amount of SIMIX processes in the system
@@ -257,7 +230,7 @@ int simcall_process_count()
  */
 void simcall_process_set_data(smx_actor_t process, void *data)
 {
-  simgrid::simix::kernelImmediate(std::bind(SIMIX_process_set_data, process, data));
+  simgrid::simix::kernelImmediate([process, data] { process->setUserData(data); });
 }
 
 /**
@@ -269,43 +242,13 @@ void simcall_process_set_kill_time(smx_actor_t process, double kill_time)
 
   if (kill_time <= SIMIX_get_clock() || simix_global->kill_process_function == nullptr)
     return;
-  XBT_DEBUG("Set kill time %f for process %s@%s", kill_time, process->cname(), process->host->cname());
-  process->kill_timer = SIMIX_timer_set(kill_time, [=] {
+  XBT_DEBUG("Set kill time %f for process %s@%s", kill_time, process->cname(), process->host->getCname());
+  process->kill_timer = SIMIX_timer_set(kill_time, [process] {
     simix_global->kill_process_function(process);
     process->kill_timer=nullptr;
   });
 }
-/**
- * \ingroup simix_process_management
- * \brief Get the kill time of a process (or 0 if unset).
- */
-double simcall_process_get_kill_time(smx_actor_t process) {
-  return SIMIX_timer_get_date(process->kill_timer);
-}
 
-/**
- * \ingroup simix_process_management
- * \brief Returns true if the process is suspended .
- *
- * This checks whether a process is suspended or not by inspecting the task on which it was waiting for the completion.
- * \param process SIMIX process
- * \return 1, if the process is suspended, else 0.
- */
-int simcall_process_is_suspended(smx_actor_t process)
-{
-  return simcall_BODY_process_is_suspended(process);
-}
-
-/**
- * \ingroup simix_process_management
- * \brief Return the properties
- *
- * This functions returns the properties associated with this process
- */
-xbt_dict_t simcall_process_get_properties(smx_actor_t process)
-{
-  return SIMIX_process_get_properties(process);
-}
 /**
  * \ingroup simix_process_management
  * \brief Add an on_exit function
@@ -315,25 +258,7 @@ XBT_PUBLIC(void) simcall_process_on_exit(smx_actor_t process, int_f_pvoid_pvoid_
 {
   simcall_BODY_process_on_exit(process, fun, data);
 }
-/**
- * \ingroup simix_process_management
- * \brief Sets the process to be auto-restarted or not by SIMIX when its host comes back up.
- * Will restart the process when the host comes back up if auto_restart is set to 1.
- */
 
-XBT_PUBLIC(void) simcall_process_auto_restart_set(smx_actor_t process, int auto_restart)
-{
-  simcall_BODY_process_auto_restart_set(process, auto_restart);
-}
-
-/**
- * \ingroup simix_process_management
- * \brief Restarts the process, killing it and starting it again from scratch.
- */
-XBT_PUBLIC(smx_actor_t) simcall_process_restart(smx_actor_t process)
-{
-  return (smx_actor_t) simcall_BODY_process_restart(process);
-}
 /**
  * \ingroup simix_process_management
  * \brief Creates a new sleep SIMIX synchro.
@@ -355,11 +280,9 @@ e_smx_state_t simcall_process_sleep(double duration)
 /**
  * \ingroup simix_comm_management
  */
-void simcall_comm_send(smx_actor_t sender, smx_mailbox_t mbox, double task_size, double rate,
-                         void *src_buff, size_t src_buff_size,
-                         int (*match_fun)(void *, void *, smx_activity_t),
-                         void (*copy_data_fun)(smx_activity_t, void*, size_t), void *data,
-                         double timeout)
+void simcall_comm_send(smx_actor_t sender, smx_mailbox_t mbox, double task_size, double rate, void* src_buff,
+                       size_t src_buff_size, int (*match_fun)(void*, void*, simgrid::kernel::activity::CommImpl*),
+                       void (*copy_data_fun)(smx_activity_t, void*, size_t), void* data, double timeout)
 {
   /* checking for infinite values */
   xbt_assert(std::isfinite(task_size), "task_size is not finite!");
@@ -385,13 +308,11 @@ void simcall_comm_send(smx_actor_t sender, smx_mailbox_t mbox, double task_size,
 /**
  * \ingroup simix_comm_management
  */
-smx_activity_t simcall_comm_isend(smx_actor_t sender, smx_mailbox_t mbox, double task_size, double rate,
-                              void *src_buff, size_t src_buff_size,
-                              int (*match_fun)(void *, void *, smx_activity_t),
-                              void (*clean_fun)(void *),
-                              void (*copy_data_fun)(smx_activity_t, void*, size_t),
-                              void *data,
-                              int detached)
+smx_activity_t simcall_comm_isend(smx_actor_t sender, smx_mailbox_t mbox, double task_size, double rate, void* src_buff,
+                                  size_t src_buff_size,
+                                  int (*match_fun)(void*, void*, simgrid::kernel::activity::CommImpl*),
+                                  void (*clean_fun)(void*), void (*copy_data_fun)(smx_activity_t, void*, size_t),
+                                  void* data, int detached)
 {
   /* checking for infinite values */
   xbt_assert(std::isfinite(task_size), "task_size is not finite!");
@@ -407,10 +328,9 @@ smx_activity_t simcall_comm_isend(smx_actor_t sender, smx_mailbox_t mbox, double
 /**
  * \ingroup simix_comm_management
  */
-void simcall_comm_recv(smx_actor_t receiver, smx_mailbox_t mbox, void *dst_buff, size_t * dst_buff_size,
-                       int (*match_fun)(void *, void *, smx_activity_t),
-                       void (*copy_data_fun)(smx_activity_t, void*, size_t),
-                       void *data, double timeout, double rate)
+void simcall_comm_recv(smx_actor_t receiver, smx_mailbox_t mbox, void* dst_buff, size_t* dst_buff_size,
+                       int (*match_fun)(void*, void*, simgrid::kernel::activity::CommImpl*),
+                       void (*copy_data_fun)(smx_activity_t, void*, size_t), void* data, double timeout, double rate)
 {
   xbt_assert(std::isfinite(timeout), "timeout is not finite!");
   xbt_assert(mbox, "No rendez-vous point defined for recv");
@@ -431,10 +351,9 @@ void simcall_comm_recv(smx_actor_t receiver, smx_mailbox_t mbox, void *dst_buff,
 /**
  * \ingroup simix_comm_management
  */
-smx_activity_t simcall_comm_irecv(smx_actor_t receiver, smx_mailbox_t mbox, void *dst_buff, size_t *dst_buff_size,
-                                int (*match_fun)(void *, void *, smx_activity_t),
-                                void (*copy_data_fun)(smx_activity_t, void*, size_t),
-                                void *data, double rate)
+smx_activity_t simcall_comm_irecv(smx_actor_t receiver, smx_mailbox_t mbox, void* dst_buff, size_t* dst_buff_size,
+                                  int (*match_fun)(void*, void*, simgrid::kernel::activity::CommImpl*),
+                                  void (*copy_data_fun)(smx_activity_t, void*, size_t), void* data, double rate)
 {
   xbt_assert(mbox, "No rendez-vous point defined for irecv");
 
@@ -445,12 +364,12 @@ smx_activity_t simcall_comm_irecv(smx_actor_t receiver, smx_mailbox_t mbox, void
 /**
  * \ingroup simix_comm_management
  */
-smx_activity_t simcall_comm_iprobe(smx_mailbox_t mbox, int type, int src, int tag,
-                                int (*match_fun)(void *, void *, smx_activity_t), void *data)
+smx_activity_t simcall_comm_iprobe(smx_mailbox_t mbox, int type,
+                                   int (*match_fun)(void*, void*, simgrid::kernel::activity::CommImpl*), void* data)
 {
   xbt_assert(mbox, "No rendez-vous point defined for iprobe");
 
-  return simcall_BODY_comm_iprobe(mbox, type, src, tag, match_fun, data);
+  return simcall_BODY_comm_iprobe(mbox, type, match_fun, data);
 }
 
 /**
@@ -526,7 +445,7 @@ smx_mutex_t simcall_mutex_init()
     fprintf(stderr,"You must run MSG_init before using MSG\n"); // We can't use xbt_die since we may get there before the initialization
     xbt_abort();
   }
-  return simcall_BODY_mutex_init();
+  return simgrid::simix::kernelImmediate([] { return new simgrid::simix::MutexImpl(); });
 }
 
 /**
@@ -604,33 +523,6 @@ void simcall_cond_broadcast(smx_cond_t cond)
   simcall_BODY_cond_broadcast(cond);
 }
 
-/**
- * \ingroup simix_synchro_management
- *
- */
-smx_sem_t simcall_sem_init(int capacity)
-{
-  return simcall_BODY_sem_init(capacity);
-}
-
-/**
- * \ingroup simix_synchro_management
- *
- */
-void simcall_sem_release(smx_sem_t sem)
-{
-  simcall_BODY_sem_release(sem);
-}
-
-/**
- * \ingroup simix_synchro_management
- *
- */
-int simcall_sem_would_block(smx_sem_t sem)
-{
-  return simcall_BODY_sem_would_block(sem);
-}
-
 /**
  * \ingroup simix_synchro_management
  *
@@ -651,91 +543,21 @@ void simcall_sem_acquire_timeout(smx_sem_t sem, double timeout)
 }
 
 /**
- * \ingroup simix_synchro_management
+ * \ingroup simix_file_management
  *
  */
-int simcall_sem_get_capacity(smx_sem_t sem)
+sg_size_t simcall_file_read(surf_file_t fd, sg_size_t size)
 {
-  return simcall_BODY_sem_get_capacity(sem);
+  return simcall_BODY_file_read(fd, size);
 }
 
 /**
  * \ingroup simix_file_management
  *
  */
-sg_size_t simcall_file_read(smx_file_t fd, sg_size_t size, sg_host_t host)
+sg_size_t simcall_file_write(surf_file_t fd, sg_size_t size)
 {
-  return simcall_BODY_file_read(fd, size, host);
-}
-
-/**
- * \ingroup simix_file_management
- *
- */
-sg_size_t simcall_file_write(smx_file_t fd, sg_size_t size, sg_host_t host)
-{
-  return simcall_BODY_file_write(fd, size, host);
-}
-
-/**
- * \ingroup simix_file_management
- * \brief
- */
-smx_file_t simcall_file_open(const char* mount, const char* path, sg_storage_t st)
-{
-  return simcall_BODY_file_open(mount, path, st);
-}
-
-/**
- * \ingroup simix_file_management
- *
- */
-int simcall_file_close(smx_file_t fd, sg_host_t host)
-{
-  return simcall_BODY_file_close(fd, host);
-}
-
-/**
- * \ingroup simix_file_management
- *
- */
-int simcall_file_unlink(smx_file_t fd, sg_host_t host)
-{
-  return simcall_BODY_file_unlink(fd, host);
-}
-
-/**
- * \ingroup simix_file_management
- *
- */
-sg_size_t simcall_file_get_size(smx_file_t fd){
-  return simcall_BODY_file_get_size(fd);
-}
-
-/**
- * \ingroup simix_file_management
- *
- */
-sg_size_t simcall_file_tell(smx_file_t fd){
-  return simcall_BODY_file_tell(fd);
-}
-
-/**
- * \ingroup simix_file_management
- *
- */
-int simcall_file_seek(smx_file_t fd, sg_offset_t offset, int origin){
-  return simcall_BODY_file_seek(fd, offset, origin);
-}
-
-/**
- * \ingroup simix_file_management
- * \brief Move a file to another location on the *same mount point*.
- *
- */
-int simcall_file_move(smx_file_t fd, const char* fullpath)
-{
-  return simcall_BODY_file_move(fd, fullpath);
+  return simcall_BODY_file_write(fd, size);
 }
 
 void simcall_run_kernel(std::function<void()> const& code)
