@@ -6,8 +6,9 @@
 #ifndef SIMIX_HOST_PRIVATE_H
 #define SIMIX_HOST_PRIVATE_H
 
-#include <vector>
 #include <functional>
+#include <map>
+#include <vector>
 
 #include <xbt/base.h>
 #include <xbt/Extendable.hpp>
@@ -39,18 +40,11 @@ namespace simgrid {
 }
 
 SG_BEGIN_DECL()
-XBT_PRIVATE void SIMIX_host_add_auto_restart_process(sg_host_t host,
-                                         const char *name,
-                                         std::function<void()> code,
-                                         void *data,
-                                         double kill_time,
-                                         xbt_dict_t properties,
-                                         int auto_restart);
+XBT_PRIVATE void SIMIX_host_add_auto_restart_process(sg_host_t host, const char* name, std::function<void()> code,
+                                                     void* data, double kill_time,
+                                                     std::map<std::string, std::string>* properties, int auto_restart);
 
 XBT_PRIVATE void SIMIX_host_autorestart(sg_host_t host);
-XBT_PRIVATE void SIMIX_execution_cancel(smx_activity_t synchro);
-XBT_PRIVATE void SIMIX_execution_set_priority(smx_activity_t synchro, double priority);
-XBT_PRIVATE void SIMIX_execution_set_bound(smx_activity_t synchro, double bound);
 
 XBT_PRIVATE void SIMIX_execution_finish(simgrid::kernel::activity::ExecImplPtr exec);
 
@@ -58,11 +52,11 @@ XBT_PRIVATE void SIMIX_set_category(smx_activity_t synchro, const char *category
 
 SG_END_DECL()
 
-XBT_PRIVATE smx_activity_t SIMIX_execution_start(smx_actor_t issuer, const char* name, double flops_amount,
-                                                 double priority, double bound);
-XBT_PRIVATE smx_activity_t SIMIX_execution_parallel_start(const char* name, int host_nb, sg_host_t* host_list,
-                                                          double* flops_amount, double* bytes_amount, double amount,
-                                                          double rate, double timeout);
+XBT_PRIVATE boost::intrusive_ptr<simgrid::kernel::activity::ExecImpl>
+SIMIX_execution_start(smx_actor_t issuer, const char* name, double flops_amount, double priority, double bound);
+XBT_PRIVATE boost::intrusive_ptr<simgrid::kernel::activity::ExecImpl>
+SIMIX_execution_parallel_start(const char* name, int host_nb, sg_host_t* host_list, double* flops_amount,
+                               double* bytes_amount, double rate, double timeout);
 
 #endif
 
