@@ -35,23 +35,22 @@ static void SIMIX_comm_start(simgrid::kernel::activity::CommImplPtr synchro);
  */
 static simgrid::kernel::activity::CommImplPtr
 _find_matching_comm(boost::circular_buffer_space_optimized<smx_activity_t>* deque, e_smx_comm_type_t type,
-                    int (*match_fun)(void*, void*, smx_activity_t), void* this_user_data, smx_activity_t my_synchro,
-                    bool remove_matching)
+                    int (*match_fun)(void*, void*, simgrid::kernel::activity::CommImpl*), void* this_user_data,
+                    simgrid::kernel::activity::CommImplPtr my_synchro, bool remove_matching)
 {
   void* other_user_data = nullptr;
 
   for(auto it = deque->begin(); it != deque->end(); it++){
-    smx_activity_t synchro = *it;
     simgrid::kernel::activity::CommImplPtr comm =
-        boost::dynamic_pointer_cast<simgrid::kernel::activity::CommImpl>(std::move(synchro));
+        boost::dynamic_pointer_cast<simgrid::kernel::activity::CommImpl>(std::move(*it));
 
     if (comm->type == SIMIX_COMM_SEND) {
       other_user_data = comm->src_data;
     } else if (comm->type == SIMIX_COMM_RECEIVE) {
       other_user_data = comm->dst_data;
     }
-    if (comm->type == type && (match_fun == nullptr || match_fun(this_user_data, other_user_data, comm)) &&
-        (not comm->match_fun || comm->match_fun(other_user_data, this_user_data, my_synchro))) {
+    if (comm->type == type && (match_fun == nullptr || match_fun(this_user_data, other_user_data, comm.get())) &&
+        (not comm->match_fun || comm->match_fun(other_user_data, this_user_data, my_synchro.get()))) {
       XBT_DEBUG("Found a matching communication synchro %p", comm.get());
       if (remove_matching)
         deque->erase(it);
@@ -72,25 +71,24 @@ _find_matching_comm(boost::circular_buffer_space_optimized<smx_activity_t>* dequ
 /******************************************************************************/
 /*                          Communication synchros                            */
 /******************************************************************************/
-XBT_PRIVATE void simcall_HANDLER_comm_send(smx_simcall_t simcall, smx_actor_t src, smx_mailbox_t mbox,
-                                  double task_size, double rate,
-                                  void *src_buff, size_t src_buff_size,
-                                  int (*match_fun)(void *, void *,smx_activity_t),
-                                  void (*copy_data_fun)(smx_activity_t, void*, size_t),
-          void *data, double timeout){
+XBT_PRIVATE void simcall_HANDLER_comm_send(smx_simcall_t simcall, smx_actor_t src, smx_mailbox_t mbox, double task_size,
+                                           double rate, void* src_buff, size_t src_buff_size,
+                                           int (*match_fun)(void*, void*, simgrid::kernel::activity::CommImpl*),
+                                           void (*copy_data_fun)(smx_activity_t, void*, size_t), void* data,
+                                           double timeout)
+{
   smx_activity_t comm = simcall_HANDLER_comm_isend(simcall, src, mbox, task_size, rate,
                            src_buff, src_buff_size, match_fun, nullptr, copy_data_fun,
                data, 0);
   SIMCALL_SET_MC_VALUE(simcall, 0);
   simcall_HANDLER_comm_wait(simcall, comm, timeout);
 }
-XBT_PRIVATE smx_activity_t simcall_HANDLER_comm_isend(smx_simcall_t simcall, smx_actor_t src_proc, smx_mailbox_t mbox,
-                                  double task_size, double rate,
-                                  void *src_buff, size_t src_buff_size,
-                                  int (*match_fun)(void *, void *,smx_activity_t),
-                                  void (*clean_fun)(void *), // used to free the synchro in case of problem after a detached send
-                                  void (*copy_data_fun)(smx_activity_t, void*, size_t),// used to copy data if not default one
-                          void *data, int detached)
+XBT_PRIVATE smx_activity_t simcall_HANDLER_comm_isend(
+    smx_simcall_t simcall, smx_actor_t src_proc, smx_mailbox_t mbox, double task_size, double rate, void* src_buff,
+    size_t src_buff_size, int (*match_fun)(void*, void*, simgrid::kernel::activity::CommImpl*),
+    void (*clean_fun)(void*), // used to free the synchro in case of problem after a detached send
+    void (*copy_data_fun)(smx_activity_t, void*, size_t), // used to copy data if not default one
+    void* data, int detached)
 {
   XBT_DEBUG("send from mailbox %p", mbox);
 
@@ -155,10 +153,10 @@ XBT_PRIVATE smx_activity_t simcall_HANDLER_comm_isend(smx_simcall_t simcall, smx
 }
 
 XBT_PRIVATE void simcall_HANDLER_comm_recv(smx_simcall_t simcall, smx_actor_t receiver, smx_mailbox_t mbox,
-                         void *dst_buff, size_t *dst_buff_size,
-                         int (*match_fun)(void *, void *, smx_activity_t),
-                         void (*copy_data_fun)(smx_activity_t, void*, size_t),
-                         void *data, double timeout, double rate)
+                                           void* dst_buff, size_t* dst_buff_size,
+                                           int (*match_fun)(void*, void*, simgrid::kernel::activity::CommImpl*),
+                                           void (*copy_data_fun)(smx_activity_t, void*, size_t), void* data,
+                                           double timeout, double rate)
 {
   smx_activity_t comm = SIMIX_comm_irecv(receiver, mbox, dst_buff, dst_buff_size, match_fun, copy_data_fun, data, rate);
   SIMCALL_SET_MC_VALUE(simcall, 0);
@@ -166,18 +164,19 @@ XBT_PRIVATE void simcall_HANDLER_comm_recv(smx_simcall_t simcall, smx_actor_t re
 }
 
 XBT_PRIVATE smx_activity_t simcall_HANDLER_comm_irecv(smx_simcall_t simcall, smx_actor_t receiver, smx_mailbox_t mbox,
-    void *dst_buff, size_t *dst_buff_size,
-    int (*match_fun)(void *, void *, smx_activity_t),
-    void (*copy_data_fun)(smx_activity_t, void*, size_t),
-    void *data, double rate)
+                                                      void* dst_buff, size_t* dst_buff_size,
+                                                      simix_match_func_t match_fun,
+                                                      void (*copy_data_fun)(smx_activity_t, void*, size_t), void* data,
+                                                      double rate)
 {
   return SIMIX_comm_irecv(receiver, mbox, dst_buff, dst_buff_size, match_fun, copy_data_fun, data, rate);
 }
 
-smx_activity_t SIMIX_comm_irecv(smx_actor_t dst_proc, smx_mailbox_t mbox, void *dst_buff, size_t *dst_buff_size,
-    int (*match_fun)(void *, void *, smx_activity_t),
-    void (*copy_data_fun)(smx_activity_t, void*, size_t), // used to copy data if not default one
-    void *data, double rate)
+smx_activity_t
+SIMIX_comm_irecv(smx_actor_t dst_proc, smx_mailbox_t mbox, void* dst_buff, size_t* dst_buff_size,
+                 int (*match_fun)(void*, void*, simgrid::kernel::activity::CommImpl*),
+                 void (*copy_data_fun)(smx_activity_t, void*, size_t), // used to copy data if not default one
+                 void* data, double rate)
 {
   simgrid::kernel::activity::CommImplPtr this_synchro =
       simgrid::kernel::activity::CommImplPtr(new simgrid::kernel::activity::CommImpl(SIMIX_COMM_RECEIVE));
@@ -194,8 +193,8 @@ smx_activity_t SIMIX_comm_irecv(smx_actor_t dst_proc, smx_mailbox_t mbox, void *
     //if not found, assume the receiver came first, register it to the mailbox in the classical way
     if (not other_comm) {
       XBT_DEBUG("We have messages in the permanent receive list, but not the one we are looking for, pushing request into list");
-      other_comm = this_synchro;
-      mbox->push(this_synchro);
+      other_comm = std::move(this_synchro);
+      mbox->push(other_comm);
     } else {
       if (other_comm->surf_comm && other_comm->remains() < 1e-12) {
         XBT_DEBUG("comm %p has been already sent, and is finished, destroy it", other_comm.get());
@@ -216,8 +215,8 @@ smx_activity_t SIMIX_comm_irecv(smx_actor_t dst_proc, smx_mailbox_t mbox, void *
 
     if (other_comm == nullptr) {
       XBT_DEBUG("Receive pushed first (%zu comm enqueued so far)", mbox->comm_queue.size());
-      other_comm = this_synchro;
-      mbox->push(this_synchro);
+      other_comm = std::move(this_synchro);
+      mbox->push(other_comm);
     } else {
       XBT_DEBUG("Match my %p with the existing %p", this_synchro.get(), other_comm.get());
 
@@ -248,15 +247,14 @@ smx_activity_t SIMIX_comm_irecv(smx_actor_t dst_proc, smx_mailbox_t mbox, void *
   return other_comm;
 }
 
-smx_activity_t simcall_HANDLER_comm_iprobe(smx_simcall_t simcall, smx_mailbox_t mbox,
-                                   int type, int src, int tag,
-                                   int (*match_fun)(void *, void *, smx_activity_t),
-                                   void *data){
-  return SIMIX_comm_iprobe(simcall->issuer, mbox, type, src, tag, match_fun, data);
+smx_activity_t simcall_HANDLER_comm_iprobe(smx_simcall_t simcall, smx_mailbox_t mbox, int type,
+                                           simix_match_func_t match_fun, void* data)
+{
+  return SIMIX_comm_iprobe(simcall->issuer, mbox, type, match_fun, data);
 }
 
-smx_activity_t SIMIX_comm_iprobe(smx_actor_t dst_proc, smx_mailbox_t mbox, int type, int src,
-                              int tag, int (*match_fun)(void *, void *, smx_activity_t), void *data)
+smx_activity_t SIMIX_comm_iprobe(smx_actor_t dst_proc, smx_mailbox_t mbox, int type, simix_match_func_t match_fun,
+                                 void* data)
 {
   XBT_DEBUG("iprobe from %p %p", mbox, &mbox->comm_queue);
   simgrid::kernel::activity::CommImplPtr this_comm;
@@ -317,7 +315,8 @@ void simcall_HANDLER_comm_wait(smx_simcall_t simcall, smx_activity_t synchro, do
   /* otherwise set up a waiting timeout on the right side          */
   if (synchro->state != SIMIX_WAITING && synchro->state != SIMIX_RUNNING) {
     SIMIX_comm_finish(synchro);
-  } else { /* if (timeout >= 0) { we need a surf sleep action even when there is no timeout, otherwise surf won't tell us when the host fails */
+  } else { /* we need a surf sleep action even when there is no timeout, otherwise surf won't tell us when the host
+              fails */
     surf_action_t sleep = simcall->issuer->host->pimpl_cpu->sleep(timeout);
     sleep->setData(&*synchro);
 
@@ -460,28 +459,28 @@ static inline void SIMIX_comm_start(simgrid::kernel::activity::CommImplPtr comm)
     comm->surf_comm->setData(comm.get());
     comm->state = SIMIX_RUNNING;
 
-    XBT_DEBUG("Starting communication %p from '%s' to '%s' (surf_action: %p)", comm.get(), sender->cname(),
-              receiver->cname(), comm->surf_comm);
+    XBT_DEBUG("Starting communication %p from '%s' to '%s' (surf_action: %p)", comm.get(), sender->getCname(),
+              receiver->getCname(), comm->surf_comm);
 
     /* If a link is failed, detect it immediately */
     if (comm->surf_comm->getState() == simgrid::surf::Action::State::failed) {
-      XBT_DEBUG("Communication from '%s' to '%s' failed to start because of a link failure", sender->cname(),
-                receiver->cname());
+      XBT_DEBUG("Communication from '%s' to '%s' failed to start because of a link failure", sender->getCname(),
+                receiver->getCname());
       comm->state = SIMIX_LINK_FAILURE;
       comm->cleanupSurf();
     }
 
     /* If any of the process is suspend, create the synchro but stop its execution,
        it will be restarted when the sender process resume */
-    if (SIMIX_process_is_suspended(comm->src_proc) || SIMIX_process_is_suspended(comm->dst_proc)) {
-      if (SIMIX_process_is_suspended(comm->src_proc))
+    if (comm->src_proc->isSuspended() || comm->dst_proc->isSuspended()) {
+      if (comm->src_proc->isSuspended())
         XBT_DEBUG("The communication is suspended on startup because src (%s@%s) was suspended since it initiated the "
                   "communication",
-                  comm->src_proc->cname(), comm->src_proc->host->cname());
+                  comm->src_proc->cname(), comm->src_proc->host->getCname());
       else
         XBT_DEBUG("The communication is suspended on startup because dst (%s@%s) was suspended since it initiated the "
                   "communication",
-                  comm->dst_proc->cname(), comm->dst_proc->host->cname());
+                  comm->dst_proc->cname(), comm->dst_proc->host->getCname());
 
       comm->surf_comm->suspend();
     }
@@ -548,7 +547,6 @@ void SIMIX_comm_finish(smx_activity_t synchro)
         case SIMIX_SRC_HOST_FAILURE:
           if (simcall->issuer == comm->src_proc)
             simcall->issuer->context->iwannadie = 1;
-          //          SMX_EXCEPTION(simcall->issuer, host_error, 0, "Host failed");
           else
             SMX_EXCEPTION(simcall->issuer, network_error, 0, "Remote peer failed");
           break;
@@ -556,7 +554,6 @@ void SIMIX_comm_finish(smx_activity_t synchro)
         case SIMIX_DST_HOST_FAILURE:
           if (simcall->issuer == comm->dst_proc)
             simcall->issuer->context->iwannadie = 1;
-          //          SMX_EXCEPTION(simcall->issuer, host_error, 0, "Host failed");
           else
             SMX_EXCEPTION(simcall->issuer, network_error, 0, "Remote peer failed");
           break;
@@ -564,9 +561,9 @@ void SIMIX_comm_finish(smx_activity_t synchro)
         case SIMIX_LINK_FAILURE:
           XBT_DEBUG("Link failure in synchro %p between '%s' and '%s': posting an exception to the issuer: %s (%p) "
                     "detached:%d",
-                    synchro.get(), comm->src_proc ? comm->src_proc->host->cname() : nullptr,
-                    comm->dst_proc ? comm->dst_proc->host->cname() : nullptr, simcall->issuer->cname(), simcall->issuer,
-                    comm->detached);
+                    synchro.get(), comm->src_proc ? comm->src_proc->host->getCname() : nullptr,
+                    comm->dst_proc ? comm->dst_proc->host->getCname() : nullptr, simcall->issuer->cname(),
+                    simcall->issuer, comm->detached);
           if (comm->src_proc == simcall->issuer) {
             XBT_DEBUG("I'm source");
           } else if (comm->dst_proc == simcall->issuer) {
@@ -688,8 +685,8 @@ void SIMIX_comm_copy_data(smx_activity_t synchro)
     return;
 
   XBT_DEBUG("Copying comm %p data from %s (%p) -> %s (%p) (%zu bytes)", comm.get(),
-            comm->src_proc ? comm->src_proc->host->cname() : "a finished process", comm->src_buff,
-            comm->dst_proc ? comm->dst_proc->host->cname() : "a finished process", comm->dst_buff, buff_size);
+            comm->src_proc ? comm->src_proc->host->getCname() : "a finished process", comm->src_buff,
+            comm->dst_proc ? comm->dst_proc->host->getCname() : "a finished process", comm->dst_buff, buff_size);
 
   /* Copy at most dst_buff_size bytes of the message to receiver's buffer */
   if (comm->dst_buff_size)
