@@ -11,6 +11,7 @@
 #include <signal.h>
 
 #include <map>
+#include <vector>
 
 /********************************** Simix Global ******************************/
 
@@ -22,8 +23,8 @@ class Global {
 
 public:
   smx_context_factory_t context_factory = nullptr;
-  xbt_dynar_t process_to_run = nullptr;
-  xbt_dynar_t process_that_ran = nullptr;
+  std::vector<smx_actor_t> process_to_run;
+  std::vector<smx_actor_t> process_that_ran;
   std::map<aid_t, smx_actor_t> process_list;
 #if SIMGRID_HAVE_MC
   /* MCer cannot read the std::map above in the remote process, so we copy the info it needs in a dynar.
@@ -76,11 +77,6 @@ XBT_PUBLIC(void) SIMIX_clean();
   _smx_throw_issuer->exception = std::make_exception_ptr(e); \
   } else ((void)0)
 
-typedef struct s_smx_file {
-  surf_file_t surf_file;
-} s_smx_file_t;
-
-
 SG_END_DECL()
 
 #endif
