@@ -8,6 +8,7 @@
 #include "simgrid/s4u/Engine.hpp"
 #include "simgrid/s4u/Host.hpp"
 #include "src/kernel/routing/NetZoneImpl.hpp"
+#include "src/kernel/routing/NetPoint.hpp"
 #include "src/surf/network_interface.hpp"
 #include "src/surf/xml/platf_private.hpp"
 #include "surf/surf.h"
@@ -27,23 +28,23 @@ static const char *instr_node_name (xbt_node_t node)
 static container_t lowestCommonAncestor (container_t a1, container_t a2)
 {
   //this is only an optimization (since most of a1 and a2 share the same parent)
-  if (a1->father == a2->father)
-    return a1->father;
+  if (a1->father_ == a2->father_)
+    return a1->father_;
 
   //create an array with all ancestors of a1
   std::vector<container_t> ancestors_a1;
-  container_t p = a1->father;
+  container_t p = a1->father_;
   while (p){
     ancestors_a1.push_back(p);
-    p = p->father;
+    p = p->father_;
   }
 
   //create an array with all ancestors of a2
   std::vector<container_t> ancestors_a2;
-  p = a2->father;
+  p = a2->father_;
   while (p){
     ancestors_a2.push_back(p);
-    p = p->father;
+    p = p->father_;
   }
 
   //find the lowest ancestor
@@ -67,7 +68,7 @@ static container_t lowestCommonAncestor (container_t a1, container_t a2)
 static void linkContainers (container_t src, container_t dst, xbt_dict_t filter)
 {
   //ignore loopback
-  if (strcmp (src->name, "__loopback__") == 0 || strcmp (dst->name, "__loopback__") == 0){
+  if (strcmp(src->name_, "__loopback__") == 0 || strcmp(dst->name_, "__loopback__") == 0) {
     XBT_DEBUG ("  linkContainers: ignoring loopback link");
     return;
   }
@@ -82,14 +83,14 @@ static void linkContainers (container_t src, container_t dst, xbt_dict_t filter)
     //check if we already register this pair (we only need one direction)
     char aux1[INSTR_DEFAULT_STR_SIZE];
     char aux2[INSTR_DEFAULT_STR_SIZE];
-    snprintf (aux1, INSTR_DEFAULT_STR_SIZE, "%s%s", src->name, dst->name);
-    snprintf (aux2, INSTR_DEFAULT_STR_SIZE, "%s%s", dst->name, src->name);
+    snprintf(aux1, INSTR_DEFAULT_STR_SIZE, "%s%s", src->name_, dst->name_);
+    snprintf(aux2, INSTR_DEFAULT_STR_SIZE, "%s%s", dst->name_, src->name_);
     if (xbt_dict_get_or_null (filter, aux1)){
-      XBT_DEBUG ("  linkContainers: already registered %s <-> %s (1)", src->name, dst->name);
+      XBT_DEBUG("  linkContainers: already registered %s <-> %s (1)", src->name_, dst->name_);
       return;
     }
     if (xbt_dict_get_or_null (filter, aux2)){
-      XBT_DEBUG ("  linkContainers: already registered %s <-> %s (2)", dst->name, src->name);
+      XBT_DEBUG("  linkContainers: already registered %s <-> %s (2)", dst->name_, src->name_);
       return;
     }
 
@@ -100,17 +101,14 @@ static void linkContainers (container_t src, container_t dst, xbt_dict_t filter)
 
   //declare type
   char link_typename[INSTR_DEFAULT_STR_SIZE];
-  snprintf (link_typename, INSTR_DEFAULT_STR_SIZE, "%s-%s%s-%s%s",
-            father->type->name,
-            src->type->name, src->type->id,
-            dst->type->name, dst->type->id);
-  type_t link_type = PJ_type_get_or_null (link_typename, father->type);
-  if (link_type == nullptr){
-    link_type = PJ_type_link_new (link_typename, father->type, src->type, dst->type);
-  }
+  snprintf(link_typename, INSTR_DEFAULT_STR_SIZE, "%s-%s%s-%s%s", father->type_->name_, src->type_->name_,
+           src->type_->id_, dst->type_->name_, dst->type_->id_);
+  simgrid::instr::Type* link_type = father->type_->getChildOrNull(link_typename);
+  if (link_type == nullptr)
+    link_type = simgrid::instr::Type::linkNew(link_typename, father->type_, src->type_, dst->type_);
 
   //register EDGE types for triva configuration
-  xbt_dict_set (trivaEdgeTypes, link_type->name, xbt_strdup("1"), nullptr);
+  trivaEdgeTypes.insert(link_type->name_);
 
   //create the link
   static long long counter = 0;
@@ -119,10 +117,10 @@ static void linkContainers (container_t src, container_t dst, xbt_dict_t filter)
   snprintf (key, INSTR_DEFAULT_STR_SIZE, "%lld", counter);
   counter++;
 
-  new StartLinkEvent(SIMIX_get_clock(), father, link_type, src, "topology", key);
-  new EndLinkEvent(SIMIX_get_clock(), father, link_type, dst, "topology", key);
+  new simgrid::instr::StartLinkEvent(SIMIX_get_clock(), father, link_type, src, "topology", key);
+  new simgrid::instr::EndLinkEvent(SIMIX_get_clock(), father, link_type, dst, "topology", key);
 
-  XBT_DEBUG ("  linkContainers %s <-> %s", src->name, dst->name);
+  XBT_DEBUG("  linkContainers %s <-> %s", src->name_, dst->name_);
 }
 
 static void recursiveGraphExtraction(simgrid::s4u::NetZone* netzone, container_t container, xbt_dict_t filter)
@@ -131,11 +129,11 @@ static void recursiveGraphExtraction(simgrid::s4u::NetZone* netzone, container_t
     XBT_DEBUG("Graph extraction disabled by user.");
     return;
   }
-  XBT_DEBUG("Graph extraction for NetZone = %s", netzone->name());
-  if (not netzone->children()->empty()) {
+  XBT_DEBUG("Graph extraction for NetZone = %s", netzone->getCname());
+  if (not netzone->getChildren()->empty()) {
     //bottom-up recursion
-    for (auto nz_son : *netzone->children()) {
-      container_t child_container = static_cast<container_t>(xbt_dict_get(container->children, nz_son->name()));
+    for (auto const& nz_son : *netzone->getChildren()) {
+      container_t child_container = static_cast<container_t>(xbt_dict_get(container->children_, nz_son->getCname()));
       recursiveGraphExtraction(nz_son, child_container, filter);
     }
   }
@@ -164,21 +162,19 @@ static void recursiveGraphExtraction(simgrid::s4u::NetZone* netzone, container_t
  */
 static void sg_instr_AS_begin(simgrid::s4u::NetZone& netzone)
 {
-  const char* id = netzone.name();
+  const char* id = netzone.getCname();
 
   if (PJ_container_get_root() == nullptr){
-    PJ_container_alloc ();
-    PJ_type_alloc();
-    container_t root = PJ_container_new (id, INSTR_AS, nullptr);
+    container_t root = new simgrid::instr::Container(id, simgrid::instr::INSTR_AS, nullptr);
     PJ_container_set_root (root);
 
     if (TRACE_smpi_is_enabled()) {
-      type_t mpi = PJ_type_get_or_null ("MPI", root->type);
+      simgrid::instr::Type* mpi = root->type_->getChildOrNull("MPI");
       if (mpi == nullptr){
-        mpi = PJ_type_container_new("MPI", root->type);
+        mpi = simgrid::instr::Type::containerNew("MPI", root->type_);
         if (not TRACE_smpi_is_grouped())
-          PJ_type_state_new ("MPI_STATE", mpi);
-        PJ_type_link_new ("MPI_LINK", PJ_type_get_root(), mpi, mpi);
+          simgrid::instr::Type::stateNew("MPI_STATE", mpi);
+        simgrid::instr::Type::linkNew("MPI_LINK", PJ_type_get_root(), mpi, mpi);
       }
     }
 
@@ -190,7 +186,7 @@ static void sg_instr_AS_begin(simgrid::s4u::NetZone& netzone)
 
   if (TRACE_needs_platform()){
     container_t father = currentContainer.back();
-    container_t container = PJ_container_new (id, INSTR_AS, father);
+    container_t container = new simgrid::instr::Container(id, simgrid::instr::INSTR_AS, father);
     currentContainer.push_back(container);
   }
 }
@@ -211,94 +207,93 @@ static void instr_routing_parse_start_link(simgrid::s4u::Link& link)
   double bandwidth_value = link.bandwidth();
   double latency_value   = link.latency();
 
-  container_t container = PJ_container_new(link.name(), INSTR_LINK, father);
+  container_t container = new simgrid::instr::Container(link.name(), simgrid::instr::INSTR_LINK, father);
 
   if ((TRACE_categorized() || TRACE_uncategorized() || TRACE_platform()) && (not TRACE_disable_link())) {
-    type_t bandwidth = PJ_type_get_or_null("bandwidth", container->type);
-    if (bandwidth == nullptr) {
-      bandwidth = PJ_type_variable_new("bandwidth", nullptr, container->type);
-    }
-    type_t latency = PJ_type_get_or_null("latency", container->type);
-    if (latency == nullptr) {
-      latency = PJ_type_variable_new("latency", nullptr, container->type);
-    }
-    new SetVariableEvent(0, container, bandwidth, bandwidth_value);
-    new SetVariableEvent(0, container, latency, latency_value);
+    simgrid::instr::Type* bandwidth = container->type_->getChildOrNull("bandwidth");
+    if (bandwidth == nullptr)
+      bandwidth = simgrid::instr::Type::variableNew("bandwidth", nullptr, container->type_);
+    simgrid::instr::Type* latency = container->type_->getChildOrNull("latency");
+    if (latency == nullptr)
+      latency = simgrid::instr::Type::variableNew("latency", nullptr, container->type_);
+    new simgrid::instr::SetVariableEvent(0, container, bandwidth, bandwidth_value);
+    new simgrid::instr::SetVariableEvent(0, container, latency, latency_value);
   }
   if (TRACE_uncategorized()) {
-    type_t bandwidth_used = PJ_type_get_or_null("bandwidth_used", container->type);
-    if (bandwidth_used == nullptr) {
-      PJ_type_variable_new("bandwidth_used", "0.5 0.5 0.5", container->type);
-    }
+    simgrid::instr::Type* bandwidth_used = container->type_->getChildOrNull("bandwidth_used");
+    if (bandwidth_used == nullptr)
+      simgrid::instr::Type::variableNew("bandwidth_used", "0.5 0.5 0.5", container->type_);
   }
 }
 
 static void sg_instr_new_host(simgrid::s4u::Host& host)
 {
   container_t father = currentContainer.back();
-  container_t container = PJ_container_new(host.cname(), INSTR_HOST, father);
+  container_t container = new simgrid::instr::Container(host.getCname(), simgrid::instr::INSTR_HOST, father);
 
   if ((TRACE_categorized() || TRACE_uncategorized() || TRACE_platform()) && (not TRACE_disable_speed())) {
-    type_t speed = PJ_type_get_or_null ("power", container->type);
+    simgrid::instr::Type* speed = container->type_->getChildOrNull("power");
     if (speed == nullptr){
-      speed = PJ_type_variable_new ("power", nullptr, container->type);
+      speed = simgrid::instr::Type::variableNew("power", nullptr, container->type_);
     }
 
-    double current_speed_state = host.speed();
-    new SetVariableEvent (0, container, speed, current_speed_state);
+    double current_speed_state = host.getSpeed();
+    new simgrid::instr::SetVariableEvent(0, container, speed, current_speed_state);
   }
   if (TRACE_uncategorized()){
-    type_t speed_used = PJ_type_get_or_null ("power_used", container->type);
+    simgrid::instr::Type* speed_used = container->type_->getChildOrNull("power_used");
     if (speed_used == nullptr){
-      PJ_type_variable_new ("power_used", "0.5 0.5 0.5", container->type);
+      simgrid::instr::Type::variableNew("power_used", "0.5 0.5 0.5", container->type_);
     }
   }
 
   if (TRACE_smpi_is_enabled() && TRACE_smpi_is_grouped()){
-    type_t mpi = PJ_type_get_or_null ("MPI", container->type);
+    simgrid::instr::Type* mpi = container->type_->getChildOrNull("MPI");
     if (mpi == nullptr){
-      mpi = PJ_type_container_new("MPI", container->type);
-      PJ_type_state_new ("MPI_STATE", mpi);
+      mpi = simgrid::instr::Type::containerNew("MPI", container->type_);
+      simgrid::instr::Type::stateNew("MPI_STATE", mpi);
     }
   }
 
   if (TRACE_msg_process_is_enabled()) {
-    type_t msg_process = PJ_type_get_or_null ("MSG_PROCESS", container->type);
+    simgrid::instr::Type* msg_process = container->type_->getChildOrNull("MSG_PROCESS");
     if (msg_process == nullptr){
-      msg_process = PJ_type_container_new("MSG_PROCESS", container->type);
-      type_t state = PJ_type_state_new ("MSG_PROCESS_STATE", msg_process);
-      PJ_value_new ("suspend", "1 0 1", state);
-      PJ_value_new ("sleep", "1 1 0", state);
-      PJ_value_new ("receive", "1 0 0", state);
-      PJ_value_new ("send", "0 0 1", state);
-      PJ_value_new ("task_execute", "0 1 1", state);
-      PJ_type_link_new ("MSG_PROCESS_LINK", PJ_type_get_root(), msg_process, msg_process);
-      PJ_type_link_new ("MSG_PROCESS_TASK_LINK", PJ_type_get_root(), msg_process, msg_process);
+      msg_process                 = simgrid::instr::Type::containerNew("MSG_PROCESS", container->type_);
+      simgrid::instr::Type* state = simgrid::instr::Type::stateNew("MSG_PROCESS_STATE", msg_process);
+      new simgrid::instr::Value("suspend", "1 0 1", state);
+      simgrid::instr::Value::get_or_new("sleep", "1 1 0", state);
+      simgrid::instr::Value::get_or_new("receive", "1 0 0", state);
+      simgrid::instr::Value::get_or_new("send", "0 0 1", state);
+      simgrid::instr::Value::get_or_new("task_execute", "0 1 1", state);
+      simgrid::instr::Type::linkNew("MSG_PROCESS_LINK", PJ_type_get_root(), msg_process, msg_process);
+      simgrid::instr::Type::linkNew("MSG_PROCESS_TASK_LINK", PJ_type_get_root(), msg_process, msg_process);
     }
   }
 
   if (TRACE_msg_vm_is_enabled()) {
-    type_t msg_vm = PJ_type_get_or_null ("MSG_VM", container->type);
+    simgrid::instr::Type* msg_vm = container->type_->getChildOrNull("MSG_VM");
     if (msg_vm == nullptr){
-      msg_vm = PJ_type_container_new("MSG_VM", container->type);
-      type_t state = PJ_type_state_new ("MSG_VM_STATE", msg_vm);
-      PJ_value_new ("suspend", "1 0 1", state);
-      PJ_value_new ("sleep", "1 1 0", state);
-      PJ_value_new ("receive", "1 0 0", state);
-      PJ_value_new ("send", "0 0 1", state);
-      PJ_value_new ("task_execute", "0 1 1", state);
-      PJ_type_link_new ("MSG_VM_LINK", PJ_type_get_root(), msg_vm, msg_vm);
-      PJ_type_link_new ("MSG_VM_PROCESS_LINK", PJ_type_get_root(), msg_vm, msg_vm);
+      msg_vm                      = simgrid::instr::Type::containerNew("MSG_VM", container->type_);
+      simgrid::instr::Type* state = simgrid::instr::Type::stateNew("MSG_VM_STATE", msg_vm);
+      new simgrid::instr::Value("suspend", "1 0 1", state);
+      simgrid::instr::Value::get_or_new("sleep", "1 1 0", state);
+      simgrid::instr::Value::get_or_new("receive", "1 0 0", state);
+      simgrid::instr::Value::get_or_new("send", "0 0 1", state);
+      simgrid::instr::Value::get_or_new("task_execute", "0 1 1", state);
+      simgrid::instr::Type::linkNew("MSG_VM_LINK", PJ_type_get_root(), msg_vm, msg_vm);
+      simgrid::instr::Type::linkNew("MSG_VM_PROCESS_LINK", PJ_type_get_root(), msg_vm, msg_vm);
     }
   }
 
 }
 
-void sg_instr_new_router(const char* name)
+static void sg_instr_new_router(simgrid::kernel::routing::NetPoint * netpoint)
 {
+  if (not netpoint->isRouter())
+    return;
   if (TRACE_is_enabled() && TRACE_needs_platform()) {
     container_t father = currentContainer.back();
-    PJ_container_new(name, INSTR_ROUTER, father);
+    new simgrid::instr::Container(netpoint->cname(), simgrid::instr::INSTR_ROUTER, father);
   }
 }
 
@@ -307,7 +302,7 @@ static void instr_routing_parse_end_platform ()
   currentContainer.clear();
   xbt_dict_t filter = xbt_dict_new_homogeneous(xbt_free_f);
   XBT_DEBUG ("Starting graph extraction.");
-  recursiveGraphExtraction(simgrid::s4u::Engine::instance()->netRoot(), PJ_container_get_root(), filter);
+  recursiveGraphExtraction(simgrid::s4u::Engine::getInstance()->getNetRoot(), PJ_container_get_root(), filter);
   XBT_DEBUG ("Graph extraction finished.");
   xbt_dict_free(&filter);
   platform_created = 1;
@@ -327,32 +322,32 @@ void instr_routing_define_callbacks ()
   }
   simgrid::s4u::NetZone::onCreation.connect(sg_instr_AS_begin);
   simgrid::s4u::NetZone::onSeal.connect(sg_instr_AS_end);
+  simgrid::kernel::routing::NetPoint::onCreation.connect(&sg_instr_new_router);
 }
-
 /*
  * user categories support
  */
-static void recursiveNewVariableType (const char *new_typename, const char *color, type_t root)
+static void recursiveNewVariableType(const char* new_typename, const char* color, simgrid::instr::Type* root)
 {
-  if (not strcmp(root->name, "HOST")) {
+  if (not strcmp(root->name_, "HOST")) {
     char tnstr[INSTR_DEFAULT_STR_SIZE];
     snprintf (tnstr, INSTR_DEFAULT_STR_SIZE, "p%s", new_typename);
-    PJ_type_variable_new (tnstr, color, root);
+    simgrid::instr::Type::variableNew(tnstr, color, root);
   }
-  if (not strcmp(root->name, "MSG_VM")) {
+  if (not strcmp(root->name_, "MSG_VM")) {
     char tnstr[INSTR_DEFAULT_STR_SIZE];
     snprintf (tnstr, INSTR_DEFAULT_STR_SIZE, "p%s", new_typename);
-    PJ_type_variable_new (tnstr, color, root);
+    simgrid::instr::Type::variableNew(tnstr, color, root);
   }
-  if (not strcmp(root->name, "LINK")) {
+  if (not strcmp(root->name_, "LINK")) {
     char tnstr[INSTR_DEFAULT_STR_SIZE];
     snprintf (tnstr, INSTR_DEFAULT_STR_SIZE, "b%s", new_typename);
-    PJ_type_variable_new (tnstr, color, root);
+    simgrid::instr::Type::variableNew(tnstr, color, root);
   }
   xbt_dict_cursor_t cursor = nullptr;
-  type_t child_type;
+  simgrid::instr::Type* child_type;
   char *name;
-  xbt_dict_foreach(root->children, cursor, name, child_type) {
+  xbt_dict_foreach (root->children_, cursor, name, child_type) {
     recursiveNewVariableType (new_typename, color, child_type);
   }
 }
@@ -362,15 +357,16 @@ void instr_new_variable_type (const char *new_typename, const char *color)
   recursiveNewVariableType (new_typename, color, PJ_type_get_root());
 }
 
-static void recursiveNewUserVariableType (const char *father_type, const char *new_typename, const char *color, type_t root)
+static void recursiveNewUserVariableType(const char* father_type, const char* new_typename, const char* color,
+                                         simgrid::instr::Type* root)
 {
-  if (not strcmp(root->name, father_type)) {
-    PJ_type_variable_new (new_typename, color, root);
+  if (not strcmp(root->name_, father_type)) {
+    simgrid::instr::Type::variableNew(new_typename, color, root);
   }
   xbt_dict_cursor_t cursor = nullptr;
-  type_t child_type;
+  simgrid::instr::Type* child_type;
   char *name;
-  xbt_dict_foreach(root->children, cursor, name, child_type) {
+  xbt_dict_foreach (root->children_, cursor, name, child_type) {
     recursiveNewUserVariableType (father_type, new_typename, color, child_type);
   }
 }
@@ -380,15 +376,15 @@ void instr_new_user_variable_type  (const char *father_type, const char *new_typ
   recursiveNewUserVariableType (father_type, new_typename, color, PJ_type_get_root());
 }
 
-static void recursiveNewUserStateType (const char *father_type, const char *new_typename, type_t root)
+static void recursiveNewUserStateType(const char* father_type, const char* new_typename, simgrid::instr::Type* root)
 {
-  if (not strcmp(root->name, father_type)) {
-    PJ_type_state_new (new_typename, root);
+  if (not strcmp(root->name_, father_type)) {
+    simgrid::instr::Type::stateNew(new_typename, root);
   }
   xbt_dict_cursor_t cursor = nullptr;
-  type_t child_type;
+  simgrid::instr::Type* child_type;
   char *name;
-  xbt_dict_foreach(root->children, cursor, name, child_type) {
+  xbt_dict_foreach (root->children_, cursor, name, child_type) {
     recursiveNewUserStateType (father_type, new_typename, child_type);
   }
 }
@@ -398,16 +394,17 @@ void instr_new_user_state_type (const char *father_type, const char *new_typenam
   recursiveNewUserStateType (father_type, new_typename, PJ_type_get_root());
 }
 
-static void recursiveNewValueForUserStateType (const char *type_name, const char *value, const char *color, type_t root)
+static void recursiveNewValueForUserStateType(const char* type_name, const char* val, const char* color,
+                                              simgrid::instr::Type* root)
 {
-  if (not strcmp(root->name, type_name)) {
-    PJ_value_new (value, color, root);
+  if (not strcmp(root->name_, type_name)) {
+    new simgrid::instr::Value(val, color, root);
   }
   xbt_dict_cursor_t cursor = nullptr;
-  type_t child_type;
+  simgrid::instr::Type* child_type;
   char *name;
-  xbt_dict_foreach(root->children, cursor, name, child_type) {
-    recursiveNewValueForUserStateType (type_name, value, color, child_type);
+  xbt_dict_foreach (root->children_, cursor, name, child_type) {
+    recursiveNewValueForUserStateType(type_name, val, color, child_type);
   }
 }
 
@@ -426,10 +423,11 @@ int instr_platform_traced ()
 static void recursiveXBTGraphExtraction(xbt_graph_t graph, xbt_dict_t nodes, xbt_dict_t edges, sg_netzone_t netzone,
                                         container_t container)
 {
-  if (not netzone->children()->empty()) {
+  if (not netzone->getChildren()->empty()) {
     //bottom-up recursion
-    for (auto netzone_child : *netzone->children()) {
-      container_t child_container = static_cast<container_t>(xbt_dict_get(container->children, netzone_child->name()));
+    for (auto const& netzone_child : *netzone->getChildren()) {
+      container_t child_container =
+          static_cast<container_t>(xbt_dict_get(container->children_, netzone_child->getCname()));
       recursiveXBTGraphExtraction(graph, nodes, edges, netzone_child, child_container);
     }
   }
@@ -442,7 +440,8 @@ xbt_graph_t instr_routing_platform_graph ()
   xbt_graph_t ret = xbt_graph_new_graph (0, nullptr);
   xbt_dict_t nodes = xbt_dict_new_homogeneous(nullptr);
   xbt_dict_t edges = xbt_dict_new_homogeneous(nullptr);
-  recursiveXBTGraphExtraction(ret, nodes, edges, simgrid::s4u::Engine::instance()->netRoot(), PJ_container_get_root());
+  recursiveXBTGraphExtraction(ret, nodes, edges, simgrid::s4u::Engine::getInstance()->getNetRoot(),
+                              PJ_container_get_root());
   xbt_dict_free (&nodes);
   xbt_dict_free (&edges);
   return ret;
