@@ -9,22 +9,12 @@
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(instr_surf, instr, "Tracing Surf");
 
-void TRACE_surf_alloc()
-{
-  TRACE_surf_resource_utilization_alloc();
-}
-
-void TRACE_surf_release()
-{
-  TRACE_surf_resource_utilization_release();
-}
-
 void TRACE_surf_host_set_speed(double date, const char *resource, double speed)
 {
   if (TRACE_categorized() || TRACE_uncategorized() || TRACE_platform()) {
     container_t container = PJ_container_get(resource);
-    type_t type = PJ_type_get ("power", container->type);
-    new SetVariableEvent(date, container, type, speed);
+    simgrid::instr::Type* type = container->type_->getChild("power");
+    new simgrid::instr::SetVariableEvent(date, container, type, speed);
   }
 }
 
@@ -32,8 +22,8 @@ void TRACE_surf_link_set_bandwidth(double date, const char *resource, double ban
 {
   if (TRACE_categorized() || TRACE_uncategorized() || TRACE_platform()) {
     container_t container = PJ_container_get(resource);
-    type_t type = PJ_type_get ("bandwidth", container->type);
-    new SetVariableEvent(date, container, type, bandwidth);
+    simgrid::instr::Type* type = container->type_->getChild("bandwidth");
+    new simgrid::instr::SetVariableEvent(date, container, type, bandwidth);
   }
 }
 
