@@ -1,5 +1,4 @@
-/* Copyright (c) 2007-2014. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2007-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -12,9 +11,9 @@
 #include "xbt/sysdep.h"
 #include "maxmin_private.hpp"
 
-#include <stdlib.h>
+#include <cstdlib>
 #ifndef MATH
-#include <math.h>
+#include <cmath>
 #endif
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(surf_lagrange, surf, "Logging specific to SURF (lagrange)");
@@ -44,16 +43,14 @@ static int __check_feasible(xbt_swag_t cnst_list, xbt_swag_t var_list, int warn)
   lmm_constraint_t cnst = nullptr;
   lmm_variable_t var = nullptr;
 
-  double tmp;
-
   xbt_swag_foreach(_cnst, cnst_list) {
-  cnst = static_cast<lmm_constraint_t>(_cnst);
-    tmp = 0;
+    cnst       = static_cast<lmm_constraint_t>(_cnst);
+    double tmp = 0;
     elem_list = &(cnst->enabled_element_set);
     xbt_swag_foreach(_elem, elem_list) {
       elem = static_cast<lmm_element_t>(_elem);
       var = elem->variable;
-      xbt_assert(var->weight > 0);
+      xbt_assert(var->sharing_weight > 0);
       tmp += var->value;
     }
 
@@ -68,7 +65,7 @@ static int __check_feasible(xbt_swag_t cnst_list, xbt_swag_t var_list, int warn)
 
   xbt_swag_foreach(_var, var_list) {
     var = static_cast<lmm_variable_t>(_var);
-    if (not var->weight)
+    if (not var->sharing_weight)
       break;
     if (var->bound < 0)
       continue;
@@ -92,7 +89,7 @@ static double new_value(lmm_variable_t var)
   }
   if (var->bound > 0)
     tmp += var->mu;
-  XBT_DEBUG("\t Working on var (%p). cost = %e; Weight = %e", var, tmp, var->weight);
+  XBT_DEBUG("\t Working on var (%p). cost = %e; Weight = %e", var, tmp, var->sharing_weight);
   //uses the partial differential inverse function
   return var->func_fpi(var, tmp);
 }
@@ -124,7 +121,7 @@ static double dual_objective(xbt_swag_t var_list, xbt_swag_t cnst_list)
     var = static_cast<lmm_variable_t>(_var);
     double sigma_i = 0.0;
 
-    if (not var->weight)
+    if (not var->sharing_weight)
       break;
 
     for (int j = 0; j < var->cnsts_number; j++)
@@ -202,7 +199,7 @@ void lagrange_solve(lmm_system_t sys)
   i = 0;
   xbt_swag_foreach(_var, var_list) {
   var = static_cast<lmm_variable_t>(_var);
-  if (not var->weight)
+  if (not var->sharing_weight)
     var->value = 0.0;
   else {
     int nb = 0;
@@ -215,12 +212,12 @@ void lagrange_solve(lmm_system_t sys)
       var->new_mu = 2.0;
       var->value  = new_value(var);
     }
-    XBT_DEBUG("#### var(%p) ->weight :  %e", var, var->weight);
+    XBT_DEBUG("#### var(%p) ->weight :  %e", var, var->sharing_weight);
     XBT_DEBUG("#### var(%p) ->mu :  %e", var, var->mu);
-    XBT_DEBUG("#### var(%p) ->weight: %e", var, var->weight);
+    XBT_DEBUG("#### var(%p) ->weight: %e", var, var->sharing_weight);
     XBT_DEBUG("#### var(%p) ->bound: %e", var, var->bound);
     for (i = 0; i < var->cnsts_number; i++) {
-      if (var->cnsts[i].value == 0.0)
+      if (var->cnsts[i].consumption_weight == 0.0)
         nb++;
     }
     if (nb == var->cnsts_number)
@@ -240,13 +237,11 @@ void lagrange_solve(lmm_system_t sys)
     /* Improve the value of mu_i */
     xbt_swag_foreach(_var, var_list) {
       var = static_cast<lmm_variable_t>(_var);
-      if (not var->weight)
+      if (not var->sharing_weight)
         break;
       if (var->bound >= 0) {
         XBT_DEBUG("Working on var (%p)", var);
         var->new_mu = new_mu(var);
-/*   dual_updated += (fabs(var->new_mu-var->mu)>dichotomy_min_error); */
-/*   XBT_DEBUG("dual_updated (%d) : %1.20f",dual_updated,fabs(var->new_mu-var->mu)); */
         XBT_DEBUG("Updating mu : var->mu (%p) : %1.20f -> %1.20f", var, var->mu, var->new_mu);
         var->mu = var->new_mu;
 
@@ -262,8 +257,6 @@ void lagrange_solve(lmm_system_t sys)
       cnst = static_cast<lmm_constraint_t>(_cnst);
       XBT_DEBUG("Working on cnst (%p)", cnst);
       cnst->new_lambda = dichotomy(cnst->lambda, partial_diff_lambda, cnst, dichotomy_min_error);
-/*       dual_updated += (fabs(cnst->new_lambda-cnst->lambda)>dichotomy_min_error); */
-/*       XBT_DEBUG("dual_updated (%d) : %1.20f",dual_updated,fabs(cnst->new_lambda-cnst->lambda)); */
       XBT_DEBUG("Updating lambda : cnst->lambda (%p) : %1.20f -> %1.20f", cnst, cnst->lambda, cnst->new_lambda);
       cnst->lambda = cnst->new_lambda;
 
@@ -278,7 +271,7 @@ void lagrange_solve(lmm_system_t sys)
     overall_modification = 0;
     xbt_swag_foreach(_var, var_list) {
       var = static_cast<lmm_variable_t>(_var);
-      if (var->weight <= 0)
+      if (var->sharing_weight <= 0)
         var->value = 0.0;
       else {
         tmp = new_value(var);
@@ -294,10 +287,6 @@ void lagrange_solve(lmm_system_t sys)
     if (not __check_feasible(cnst_list, var_list, 0))
       overall_modification = 1.0;
     XBT_DEBUG("Iteration %d: overall_modification : %f", iteration, overall_modification);
-    /*     if(not dual_updated) { */
-    /*       XBT_WARN("Could not improve the convergence at iteration %d. Drop it!",iteration); */
-    /*       break; */
-    /*     } */
   }
 
   __check_feasible(cnst_list, var_list, 1);
@@ -394,25 +383,20 @@ static double dichotomy(double init, double diff(double, void *), void *var_cnst
         min = middle;
         overall_error = max_diff - middle_diff;
         min_diff = middle_diff;
-/*   SHOW_EXPR(overall_error); */
       } else if (middle_diff > 0) {
         XBT_CDEBUG(surf_lagrange_dichotomy, "Decreasing max");
         max = middle;
         overall_error = max_diff - middle_diff;
         max_diff = middle_diff;
-/*   SHOW_EXPR(overall_error); */
       } else {
         overall_error = 0;
-/*   SHOW_EXPR(overall_error); */
       }
     } else if (fabs(min_diff) < 1e-20) {
       max = min;
       overall_error = 0;
-/*       SHOW_EXPR(overall_error); */
     } else if (fabs(max_diff) < 1e-20) {
       min = max;
       overall_error = 0;
-/*       SHOW_EXPR(overall_error); */
     } else if (min_diff > 0 && max_diff < 0) {
       XBT_CWARN(surf_lagrange_dichotomy, "The impossible happened, partial_diff(min) > 0 && partial_diff(max) < 0");
       xbt_abort();
@@ -431,30 +415,25 @@ static double dichotomy(double init, double diff(double, void *), void *var_cnst
 
 static double partial_diff_lambda(double lambda, void *param_cnst)
 {
-  int j;
-  void *_elem;
-  xbt_swag_t elem_list = nullptr;
-  lmm_element_t elem = nullptr;
-  lmm_variable_t var = nullptr;
   lmm_constraint_t cnst = static_cast<lmm_constraint_t>(param_cnst);
   double diff = 0.0;
-  double sigma_i = 0.0;
 
   XBT_IN();
-  elem_list = &(cnst->enabled_element_set);
 
   XBT_CDEBUG(surf_lagrange_dichotomy, "Computing diff of cnst (%p)", cnst);
 
+  xbt_swag_t elem_list = &(cnst->enabled_element_set);
+  void* _elem;
   xbt_swag_foreach(_elem, elem_list) {
-  elem = static_cast<lmm_element_t>(_elem);
-    var = elem->variable;
-    xbt_assert(var->weight > 0);
+    lmm_element_t elem = static_cast<lmm_element_t>(_elem);
+    lmm_variable_t var = elem->variable;
+    xbt_assert(var->sharing_weight > 0);
     XBT_CDEBUG(surf_lagrange_dichotomy, "Computing sigma_i for var (%p)", var);
     // Initialize the summation variable
-    sigma_i = 0.0;
+    double sigma_i = 0.0;
 
     // Compute sigma_i
-    for (j = 0; j < var->cnsts_number; j++) {
+    for (int j = 0; j < var->cnsts_number; j++) {
       sigma_i += (var->cnsts[j].constraint)->lambda;
     }
 
@@ -505,19 +484,19 @@ void lmm_set_default_protocol_function(double (*func_f) (lmm_variable_t var, dou
 double func_vegas_f(lmm_variable_t var, double x)
 {
   xbt_assert(x > 0.0, "Don't call me with stupid values! (%1.20f)", x);
-  return VEGAS_SCALING * var->weight * log(x);
+  return VEGAS_SCALING * var->sharing_weight * log(x);
 }
 
 double func_vegas_fp(lmm_variable_t var, double x)
 {
   xbt_assert(x > 0.0, "Don't call me with stupid values! (%1.20f)", x);
-  return VEGAS_SCALING * var->weight / x;
+  return VEGAS_SCALING * var->sharing_weight / x;
 }
 
 double func_vegas_fpi(lmm_variable_t var, double x)
 {
   xbt_assert(x > 0.0, "Don't call me with stupid values! (%1.20f)", x);
-  return var->weight / (x / VEGAS_SCALING);
+  return var->sharing_weight / (x / VEGAS_SCALING);
 }
 
 /*
@@ -528,27 +507,27 @@ double func_vegas_fpi(lmm_variable_t var, double x)
 #define RENO_SCALING 1.0
 double func_reno_f(lmm_variable_t var, double x)
 {
-  xbt_assert(var->weight > 0.0, "Don't call me with stupid values!");
+  xbt_assert(var->sharing_weight > 0.0, "Don't call me with stupid values!");
 
-  return RENO_SCALING * sqrt(3.0 / 2.0) / var->weight * atan(sqrt(3.0 / 2.0) * var->weight * x);
+  return RENO_SCALING * sqrt(3.0 / 2.0) / var->sharing_weight * atan(sqrt(3.0 / 2.0) * var->sharing_weight * x);
 }
 
 double func_reno_fp(lmm_variable_t var, double x)
 {
-  return RENO_SCALING * 3.0 / (3.0 * var->weight * var->weight * x * x + 2.0);
+  return RENO_SCALING * 3.0 / (3.0 * var->sharing_weight * var->sharing_weight * x * x + 2.0);
 }
 
 double func_reno_fpi(lmm_variable_t var, double x)
 {
   double res_fpi;
 
-  xbt_assert(var->weight > 0.0, "Don't call me with stupid values!");
+  xbt_assert(var->sharing_weight > 0.0, "Don't call me with stupid values!");
   xbt_assert(x > 0.0, "Don't call me with stupid values!");
 
-  res_fpi = 1.0 / (var->weight * var->weight * (x / RENO_SCALING)) - 2.0 / (3.0 * var->weight * var->weight);
+  res_fpi = 1.0 / (var->sharing_weight * var->sharing_weight * (x / RENO_SCALING)) -
+            2.0 / (3.0 * var->sharing_weight * var->sharing_weight);
   if (res_fpi <= 0.0)
     return 0.0;
-/*   xbt_assert(res_fpi>0.0,"Don't call me with stupid values!"); */
   return sqrt(res_fpi);
 }
 
@@ -560,19 +539,20 @@ double func_reno_fpi(lmm_variable_t var, double x)
 #define RENO2_SCALING 1.0
 double func_reno2_f(lmm_variable_t var, double x)
 {
-  xbt_assert(var->weight > 0.0, "Don't call me with stupid values!");
-  return RENO2_SCALING * (1.0 / var->weight) * log((x * var->weight) / (2.0 * x * var->weight + 3.0));
+  xbt_assert(var->sharing_weight > 0.0, "Don't call me with stupid values!");
+  return RENO2_SCALING * (1.0 / var->sharing_weight) *
+         log((x * var->sharing_weight) / (2.0 * x * var->sharing_weight + 3.0));
 }
 
 double func_reno2_fp(lmm_variable_t var, double x)
 {
-  return RENO2_SCALING * 3.0 / (var->weight * x * (2.0 * var->weight * x + 3.0));
+  return RENO2_SCALING * 3.0 / (var->sharing_weight * x * (2.0 * var->sharing_weight * x + 3.0));
 }
 
 double func_reno2_fpi(lmm_variable_t var, double x)
 {
   xbt_assert(x > 0.0, "Don't call me with stupid values!");
-  double tmp = x * var->weight * var->weight;
+  double tmp     = x * var->sharing_weight * var->sharing_weight;
   double res_fpi = tmp * (9.0 * x + 24.0);
 
   if (res_fpi <= 0.0)
