@@ -54,36 +54,26 @@ NetPointNs3::NetPointNs3()
  * Callbacks *
  *************/
 
-static void clusterCreation_cb(sg_platf_cluster_cbarg_t cluster)
+static void clusterCreation_cb(ClusterCreationArgs* cluster)
 {
-  char* lat = bprintf("%fs", cluster->lat);
-  char* bw  = bprintf("%fbps", cluster->bw * 8);
-
-  for (int i : *cluster->radicals) {
+  for (int const& i : *cluster->radicals) {
     // Routers don't create a router on the other end of the private link by themselves.
     // We just need this router to be given an ID so we create a temporary NetPointNS3 so that it gets one
     NetPointNs3* host_dst = new NetPointNs3();
 
     // Create private link
-    char* host_id = bprintf("%s%d%s", cluster->prefix, i, cluster->suffix);
-    NetPointNs3* host_src = sg_host_by_name(host_id)->pimpl_netpoint->extension<NetPointNs3>();
-    xbt_assert(host_src, "Cannot find a NS3 host of name %s", host_id);
+    std::string host_id   = cluster->prefix + std::to_string(i) + cluster->suffix;
+    NetPointNs3* host_src = sg_host_by_name(host_id.c_str())->pimpl_netpoint->extension<NetPointNs3>();
+    xbt_assert(host_src, "Cannot find a NS3 host of name %s", host_id.c_str());
 
     // Any NS3 route is symmetrical
-    ns3_add_link(host_src, host_dst, bw, lat);
+    ns3_add_link(host_src, host_dst, cluster->bw, cluster->lat);
 
     delete host_dst;
-    free(host_id);
   }
-  xbt_free(lat);
-  xbt_free(bw);
 
   //Create link backbone
-  lat = bprintf("%fs", cluster->bb_lat);
-  bw =  bprintf("%fBps", cluster->bb_bw);
-  ns3_add_cluster(cluster->id, bw, lat);
-  xbt_free(lat);
-  xbt_free(bw);
+  ns3_add_cluster(cluster->id.c_str(), cluster->bb_bw, cluster->bb_lat);
 }
 
 static void routeCreation_cb(bool symmetrical, simgrid::kernel::routing::NetPoint* src,
@@ -96,11 +86,10 @@ static void routeCreation_cb(bool symmetrical, simgrid::kernel::routing::NetPoin
 
     XBT_DEBUG("Route from '%s' to '%s' with link '%s' %s", src->cname(), dst->cname(), link->cname(),
               (symmetrical ? "(symmetrical)" : "(not symmetrical)"));
-    char* link_bdw = bprintf("%fbps", link->bandwidth() * 8);
-    char* link_lat = bprintf("%fs", link->latency());
 
     //   XBT_DEBUG("src (%s), dst (%s), src_id = %d, dst_id = %d",src,dst, src_id, dst_id);
-    XBT_DEBUG("\tLink (%s) bdw:%s lat:%s", link->cname(), link_bdw, link_lat);
+    XBT_DEBUG("\tLink (%s) bw:%fbps lat:%fs", link->cname(), link->bandwidth(),
+        link->latency());
 
     // create link ns3
     NetPointNs3* host_src = src->extension<NetPointNs3>();
@@ -109,11 +98,7 @@ static void routeCreation_cb(bool symmetrical, simgrid::kernel::routing::NetPoin
     xbt_assert(host_src != nullptr, "Network element %s does not seem to be NS3-ready", src->cname());
     xbt_assert(host_dst != nullptr, "Network element %s does not seem to be NS3-ready", dst->cname());
 
-    // Any NS3 route is symmetrical
-    ns3_add_link(host_src, host_dst, link_bdw, link_lat);
-
-    xbt_free(link_bdw);
-    xbt_free(link_lat);
+    ns3_add_link(host_src, host_dst, link->bandwidth(), link->latency());
   } else {
     static bool warned_about_long_routes = false;
 
@@ -150,8 +135,7 @@ void surf_network_model_init_NS3()
 }
 
 static simgrid::config::Flag<std::string> ns3_tcp_model("ns3/TcpModel",
-  "The ns3 tcp model can be : NewReno or Reno or Tahoe",
-  "default");
+    "The ns3 tcp model can be : NewReno or Reno or Tahoe", "NewReno");
 
 namespace simgrid {
 namespace surf {
@@ -159,6 +143,7 @@ namespace surf {
 NetworkNS3Model::NetworkNS3Model() : NetworkModel() {
   NetPointNs3::EXTENSION_ID = simgrid::kernel::routing::NetPoint::extension_create<NetPointNs3>();
 
+  flowFromSock = xbt_dict_new_homogeneous([](void* p) { delete static_cast<SgFlow*>(p); });
   ns3_initialize(ns3_tcp_model.get().c_str());
 
   simgrid::kernel::routing::NetPoint::onCreation.connect([](simgrid::kernel::routing::NetPoint* pt) {
@@ -169,18 +154,19 @@ NetworkNS3Model::NetworkNS3Model() : NetworkModel() {
   simgrid::s4u::onPlatformCreated.connect(&postparse_cb);
   simgrid::s4u::NetZone::onRouteCreation.connect(&routeCreation_cb);
 
+  LogComponentEnable("PacketSink", ns3::LOG_LEVEL_INFO);
   LogComponentEnable("UdpEchoClientApplication", ns3::LOG_LEVEL_INFO);
   LogComponentEnable("UdpEchoServerApplication", ns3::LOG_LEVEL_INFO);
 }
 
 NetworkNS3Model::~NetworkNS3Model() {
-  for (auto addr : IPV4addr)
+  for (auto const& addr : IPV4addr)
     free(addr);
   IPV4addr.clear();
   xbt_dict_free(&flowFromSock);
 }
 
-LinkImpl* NetworkNS3Model::createLink(const char* name, double bandwidth, double latency,
+LinkImpl* NetworkNS3Model::createLink(const std::string& name, double bandwidth, double latency,
                                       e_surf_link_sharing_policy_t policy)
 {
   return new LinkNS3(this, name, bandwidth, latency);
@@ -241,7 +227,7 @@ void NetworkNS3Model::updateActionsState(double now, double delta)
       std::vector<LinkImpl*> route = std::vector<LinkImpl*>();
 
       action->src_->routeTo(action->dst_, &route, nullptr);
-      for (auto link : route)
+      for (auto const& link : route)
         TRACE_surf_link_set_utilization(link->cname(), action->getCategory(), (data_delta_sent) / delta, now - delta,
                                         delta);
 
@@ -251,8 +237,7 @@ void NetworkNS3Model::updateActionsState(double now, double delta)
     if(sgFlow->finished_){
       xbt_dynar_push(socket_to_destroy,&ns3Socket);
       XBT_DEBUG("Destroy socket %p of action %p", ns3Socket, action);
-      action->finish();
-      action->setState(Action::State::done);
+      action->finish(Action::State::done);
     }
   }
 
@@ -260,7 +245,7 @@ void NetworkNS3Model::updateActionsState(double now, double delta)
     xbt_dynar_pop(socket_to_destroy,&ns3Socket);
 
     if (XBT_LOG_ISENABLED(ns3, xbt_log_priority_debug)) {
-      SgFlow *flow = (SgFlow*)xbt_dict_get (flowFromSock, ns3Socket);
+      SgFlow* flow = static_cast<SgFlow*>(xbt_dict_get(flowFromSock, ns3Socket));
       XBT_DEBUG ("Removing socket %p of action %p", ns3Socket, flow->action_);
     }
     xbt_dict_remove(flowFromSock, ns3Socket);
@@ -271,7 +256,7 @@ void NetworkNS3Model::updateActionsState(double now, double delta)
  * Resource *
  ************/
 
-LinkNS3::LinkNS3(NetworkNS3Model* model, const char* name, double bandwidth, double latency)
+LinkNS3::LinkNS3(NetworkNS3Model* model, const std::string& name, double bandwidth, double latency)
     : LinkImpl(model, name, nullptr)
 {
   bandwidth_.peak = bandwidth;
@@ -300,11 +285,11 @@ void LinkNS3::setLatencyTrace(tmgr_trace_t trace) {
 NetworkNS3Action::NetworkNS3Action(Model* model, double size, s4u::Host* src, s4u::Host* dst)
     : NetworkAction(model, size, false)
 {
-  XBT_DEBUG("Communicate from %s to %s", src->cname(), dst->cname());
+  XBT_DEBUG("Communicate from %s to %s", src->getCname(), dst->getCname());
 
   src_ = src;
   dst_ = dst;
-  ns3_create_flow(src, dst, surf_get_clock(), size, this);
+  ns3_create_flow(src, dst, size, this);
 
   s4u::Link::onCommunicate(this, src, dst);
 }
@@ -352,9 +337,9 @@ void ns3_simulator(double maxSeconds)
   ns3::Simulator::Run ();
 }
 
-void ns3_create_flow(simgrid::s4u::Host* src, simgrid::s4u::Host* dst, double startTime, u_int32_t TotalBytes,
-                     simgrid::surf::NetworkNS3Action* action)
-{
+void ns3_create_flow(simgrid::s4u::Host* src, simgrid::s4u::Host* dst,
+    u_int32_t TotalBytes,
+    simgrid::surf::NetworkNS3Action* action) {
   unsigned int node1 = src->pimpl_netpoint->extension<NetPointNs3>()->node_num;
   unsigned int node2 = dst->pimpl_netpoint->extension<NetPointNs3>()->node_num;
 
@@ -367,20 +352,17 @@ void ns3_create_flow(simgrid::s4u::Host* src, simgrid::s4u::Host* dst, double st
   xbt_assert(addr != nullptr, "Element %s is unknown to NS3. Is it connected to any one-hop link?",
              dst->pimpl_netpoint->cname());
 
-  XBT_DEBUG("ns3_create_flow %d Bytes from %d to %d with Interface %s",TotalBytes, node1, node2,addr);
+  XBT_DEBUG("ns3_create_flow %u Bytes from %u to %u with Interface %s", TotalBytes, node1, node2, addr);
   ns3::PacketSinkHelper sink("ns3::TcpSocketFactory", ns3::InetSocketAddress (ns3::Ipv4Address::GetAny(), port_number));
   sink.Install (dst_node);
 
-  ns3::Ptr<ns3::Socket> sock = ns3::Socket::CreateSocket (src_node, ns3::TcpSocketFactory::GetTypeId());
+  ns3::Ptr<ns3::Socket> sock = ns3::Socket::CreateSocket(src_node, ns3::TcpSocketFactory::GetTypeId());
 
   xbt_dict_set(flowFromSock, transformSocketPtr(sock), new SgFlow(TotalBytes, action), nullptr);
 
   sock->Bind(ns3::InetSocketAddress(port_number));
-  XBT_DEBUG("Create flow starting to %fs + %fs = %fs",
-      startTime-ns3::Simulator::Now().GetSeconds(), ns3::Simulator::Now().GetSeconds(), startTime);
 
-  ns3::Simulator::Schedule (ns3::Seconds(startTime-ns3::Simulator::Now().GetSeconds()),
-      &StartFlow, sock, addr, port_number);
+  ns3::Simulator::ScheduleNow(&StartFlow, sock, addr, port_number);
 
   port_number++;
   xbt_assert(port_number <= 65000, "Too many connections! Port number is saturated.");
@@ -393,8 +375,9 @@ void ns3_initialize(const char* TcpProtocol){
 //  "ns3::TcpReno"
 //  "ns3::TcpTahoe"
 
-  ns3::Config::SetDefault ("ns3::TcpSocket::SegmentSize", ns3::UintegerValue (1024)); // 1024-byte packet for easier reading
+  ns3::Config::SetDefault ("ns3::TcpSocket::SegmentSize", ns3::UintegerValue (1000));
   ns3::Config::SetDefault ("ns3::TcpSocket::DelAckCount", ns3::UintegerValue (1));
+  ns3::Config::SetDefault ("ns3::TcpSocketBase::Timestamp", ns3::BooleanValue (false));
 
   if (not strcmp(TcpProtocol, "default"))
     return;
@@ -418,24 +401,23 @@ void ns3_initialize(const char* TcpProtocol){
   xbt_die("The ns3/TcpModel must be : NewReno or Reno or Tahoe");
 }
 
-void ns3_add_cluster(const char* id, char* bw, char* lat)
-{
+void ns3_add_cluster(const char* id, double bw, double lat) {
   ns3::NodeContainer Nodes;
 
   for (unsigned int i = number_of_clusters_nodes; i < Cluster_nodes.GetN(); i++) {
     Nodes.Add(Cluster_nodes.Get(i));
-    XBT_DEBUG("Add node %d to cluster",i);
+    XBT_DEBUG("Add node %u to cluster", i);
   }
   number_of_clusters_nodes = Cluster_nodes.GetN();
 
-  XBT_DEBUG("Add router %d to cluster",nodes.GetN()-Nodes.GetN()-1);
+  XBT_DEBUG("Add router %u to cluster", nodes.GetN() - Nodes.GetN() - 1);
   Nodes.Add(nodes.Get(nodes.GetN()-Nodes.GetN()-1));
 
   xbt_assert(Nodes.GetN() <= 65000, "Cluster with NS3 is limited to 65000 nodes");
   ns3::CsmaHelper csma;
-  csma.SetChannelAttribute ("DataRate", ns3::StringValue (bw));
-  csma.SetChannelAttribute ("Delay", ns3::StringValue (lat));
-  ns3::NetDeviceContainer devices = csma.Install (Nodes);
+  csma.SetDeviceAttribute("DataRate", ns3::DataRateValue(ns3::DataRate(bw*8)));// NS3 takes bps, but we provide Bps
+  csma.SetChannelAttribute("Delay", ns3::TimeValue(ns3::Seconds(lat)));
+  ns3::NetDeviceContainer devices = csma.Install(Nodes);
   XBT_DEBUG("Create CSMA");
 
   char * adr = bprintf("%d.%d.0.0",number_of_networks,number_of_links);
@@ -452,7 +434,7 @@ void ns3_add_cluster(const char* id, char* bw, char* lat)
   }else{
     number_of_links++;
   }
-  XBT_DEBUG("Number of nodes in Cluster_nodes: %d",Cluster_nodes.GetN());
+  XBT_DEBUG("Number of nodes in Cluster_nodes: %u", Cluster_nodes.GetN());
 }
 
 static char* transformIpv4Address (ns3::Ipv4Address from){
@@ -462,8 +444,7 @@ static char* transformIpv4Address (ns3::Ipv4Address from){
   return bprintf("%s",s.c_str());
 }
 
-void ns3_add_link(NetPointNs3* src, NetPointNs3* dst, char* bw, char* lat)
-{
+void ns3_add_link(NetPointNs3* src, NetPointNs3* dst, double bw, double lat) {
   ns3::PointToPointHelper pointToPoint;
 
   ns3::Ipv4AddressHelper address;
@@ -474,9 +455,15 @@ void ns3_add_link(NetPointNs3* src, NetPointNs3* dst, char* bw, char* lat)
   ns3::Ptr<ns3::Node> a = nodes.Get(srcNum);
   ns3::Ptr<ns3::Node> b = nodes.Get(dstNum);
 
-  XBT_DEBUG("\tAdd PTP from %d to %d bw:'%s' lat:'%s'", srcNum, dstNum, bw, lat);
-  pointToPoint.SetDeviceAttribute ("DataRate", ns3::StringValue (bw));
-  pointToPoint.SetChannelAttribute ("Delay", ns3::StringValue (lat));
+  XBT_DEBUG("\tAdd PTP from %d to %d bw:'%f Bps' lat:'%fs'", srcNum, dstNum, bw, lat);
+  pointToPoint.SetDeviceAttribute("DataRate", ns3::DataRateValue(ns3::DataRate(bw*8)));// NS3 takes bps, but we provide Bps
+  pointToPoint.SetChannelAttribute("Delay", ns3::TimeValue(ns3::Seconds(lat)));
+
+  char *filename = bprintf("link-%d-%d.tr", srcNum, dstNum);
+  ns3::AsciiTraceHelper ascii;
+  pointToPoint.EnableAsciiAll (ascii.CreateFileStream (filename));
+  pointToPoint.EnablePcapAll ("tcp-bulk-send", false);
+  xbt_free(filename);
 
   ns3::NetDeviceContainer netA;
   netA.Add(pointToPoint.Install (a, b));
