@@ -12,6 +12,8 @@
 #include "src/surf/HostImpl.hpp"
 
 #include <fstream>
+#include <set>
+#include <string>
 #include <vector>
 
 XBT_LOG_NEW_CATEGORY(surf, "All SURF categories");
@@ -26,8 +28,9 @@ std::vector<surf_model_t> * all_existing_models = nullptr; /* to destroy models
 simgrid::trace_mgr::future_evt_set *future_evt_set = nullptr;
 std::vector<std::string> surf_path;
 std::vector<simgrid::s4u::Host*> host_that_restart;
-xbt_dict_t watched_hosts_lib;
-extern std::map<std::string, storage_type_t> storage_types;
+/**  set of hosts for which one want to be notified if they ever restart. */
+std::set<std::string> watched_hosts;
+extern std::map<std::string, simgrid::surf::StorageType*> storage_types;
 
 namespace simgrid {
 namespace surf {
@@ -36,8 +39,8 @@ simgrid::xbt::signal<void()> surfExitCallbacks;
 }
 }
 
-#include <simgrid/plugins/energy.h> // FIXME: this plugin should not be linked to the core
-#include <simgrid/plugins/load.h>   // FIXME: this plugin should not be linked to the core
+#include <simgrid/plugins/energy.h> // FIXME: this plug-in should not be linked to the core
+#include <simgrid/plugins/load.h>   // FIXME: this plug-in should not be linked to the core
 
 s_surf_model_description_t surf_plugin_description[] = {
     {"Energy", "Cpu energy consumption.", &sg_host_energy_plugin_init},
@@ -47,25 +50,31 @@ s_surf_model_description_t surf_plugin_description[] = {
 
 /* Don't forget to update the option description in smx_config when you change this */
 s_surf_model_description_t surf_network_model_description[] = {
-  {"LV08", "Realistic network analytic model (slow-start modeled by multiplying latency by 10.4, bandwidth by .92; bottleneck sharing uses a payload of S=8775 for evaluating RTT). ",
-   &surf_network_model_init_LegrandVelho},
-  {"Constant",
-   "Simplistic network model where all communication take a constant time (one second). This model provides the lowest realism, but is (marginally) faster.",
-   &surf_network_model_init_Constant},
-  {"SMPI", "Realistic network model specifically tailored for HPC settings (accurate modeling of slow start with correction factors on three intervals: < 1KiB, < 64 KiB, >= 64 KiB)",
-   &surf_network_model_init_SMPI},
-  {"IB", "Realistic network model specifically tailored for HPC settings, with Infiniband contention model",
-   &surf_network_model_init_IB},
-  {"CM02", "Legacy network analytic model (Very similar to LV08, but without corrective factors. The timings of small messages are thus poorly modeled).",
-   &surf_network_model_init_CM02},
-  {"NS3", "Network pseudo-model using the NS3 tcp model instead of an analytic model", &surf_network_model_init_NS3},
-  {"Reno",  "Model from Steven H. Low using lagrange_solve instead of lmm_solve (experts only; check the code for more info).",
-   &surf_network_model_init_Reno},
-  {"Reno2", "Model from Steven H. Low using lagrange_solve instead of lmm_solve (experts only; check the code for more info).",
-   &surf_network_model_init_Reno2},
-  {"Vegas", "Model from Steven H. Low using lagrange_solve instead of lmm_solve (experts only; check the code for more info).",
-   &surf_network_model_init_Vegas},
-  {nullptr, nullptr, nullptr}      /* this array must be nullptr terminated */
+    {"LV08", "Realistic network analytic model (slow-start modeled by multiplying latency by 13.01, bandwidth by .97; "
+             "bottleneck sharing uses a payload of S=20537 for evaluating RTT). ",
+     &surf_network_model_init_LegrandVelho},
+    {"Constant", "Simplistic network model where all communication take a constant time (one second). This model "
+                 "provides the lowest realism, but is (marginally) faster.",
+     &surf_network_model_init_Constant},
+    {"SMPI", "Realistic network model specifically tailored for HPC settings (accurate modeling of slow start with "
+             "correction factors on three intervals: < 1KiB, < 64 KiB, >= 64 KiB)",
+     &surf_network_model_init_SMPI},
+    {"IB", "Realistic network model specifically tailored for HPC settings, with Infiniband contention model",
+     &surf_network_model_init_IB},
+    {"CM02", "Legacy network analytic model (Very similar to LV08, but without corrective factors. The timings of "
+             "small messages are thus poorly modeled).",
+     &surf_network_model_init_CM02},
+    {"NS3", "Network pseudo-model using the NS3 tcp model instead of an analytic model", &surf_network_model_init_NS3},
+    {"Reno",
+     "Model from Steven H. Low using lagrange_solve instead of lmm_solve (experts only; check the code for more info).",
+     &surf_network_model_init_Reno},
+    {"Reno2",
+     "Model from Steven H. Low using lagrange_solve instead of lmm_solve (experts only; check the code for more info).",
+     &surf_network_model_init_Reno2},
+    {"Vegas",
+     "Model from Steven H. Low using lagrange_solve instead of lmm_solve (experts only; check the code for more info).",
+     &surf_network_model_init_Vegas},
+    {nullptr, nullptr, nullptr} /* this array must be nullptr terminated */
 };
 
 #if ! HAVE_SMPI
@@ -106,10 +115,6 @@ s_surf_model_description_t surf_storage_model_description[] = {
   {nullptr, nullptr,  nullptr}      /* this array must be nullptr terminated */
 };
 
-#if HAVE_THREAD_CONTEXTS
-static xbt_parmap_t surf_parmap = nullptr; /* parallel map on models */
-#endif
-
 double NOW = 0;
 
 double surf_get_clock()
@@ -123,16 +128,16 @@ double surf_get_clock()
 # define FILE_DELIM "/"         /* FIXME: move to better location */
 #endif
 
-std::ifstream* surf_ifsopen(const char* name)
+std::ifstream* surf_ifsopen(std::string name)
 {
   std::ifstream* fs = new std::ifstream();
-  xbt_assert(name);
-  if (__surf_is_absolute_file_path(name)) { /* don't mess with absolute file names */
-    fs->open(name, std::ifstream::in);
+  xbt_assert(not name.empty());
+  if (__surf_is_absolute_file_path(name.c_str())) { /* don't mess with absolute file names */
+    fs->open(name.c_str(), std::ifstream::in);
   }
 
   /* search relative files in the path */
-  for (auto path_elm : surf_path) {
+  for (auto const& path_elm : surf_path) {
     std::string buff = path_elm + FILE_DELIM + name;
     fs->open(buff.c_str(), std::ifstream::in);
 
@@ -144,6 +149,7 @@ std::ifstream* surf_ifsopen(const char* name)
 
   return fs;
 }
+
 FILE *surf_fopen(const char *name, const char *mode)
 {
   FILE *file = nullptr;
@@ -154,10 +160,9 @@ FILE *surf_fopen(const char *name, const char *mode)
     return fopen(name, mode);
 
   /* search relative files in the path */
-  for (auto path_elm : surf_path) {
-    char* buff = bprintf("%s" FILE_DELIM "%s", path_elm.c_str(), name);
-    file = fopen(buff, mode);
-    free(buff);
+  for (auto const& path_elm : surf_path) {
+    std::string buff = path_elm + FILE_DELIM + name;
+    file             = fopen(buff.c_str(), mode);
 
     if (file)
       return file;
@@ -234,20 +239,18 @@ void model_help(const char *category, s_surf_model_description_t * table)
     printf("  %s: %s\n", table[i].name, table[i].description);
 }
 
-int find_model_description(s_surf_model_description_t * table,
-                           const char *name)
+int find_model_description(s_surf_model_description_t* table, const char* name)
 {
-  int i;
-  char *name_list = nullptr;
-
-  for (i = 0; table[i].name; i++)
+  for (int i = 0; table[i].name; i++)
     if (not strcmp(name, table[i].name)) {
       return i;
     }
+
   if (not table[0].name)
     xbt_die("No model is valid! This is a bug.");
-  name_list = xbt_strdup(table[0].name);
-  for (i = 1; table[i].name; i++) {
+
+  char* name_list = xbt_strdup(table[0].name);
+  for (int i = 1; table[i].name; i++) {
     name_list = (char *) xbt_realloc(name_list, strlen(name_list) + strlen(table[i].name) + 3);
     strncat(name_list, ", ", 2);
     strncat(name_list, table[i].name, strlen(table[i].name));
@@ -340,17 +343,12 @@ void surf_init(int *argc, char **argv)
   XBT_DEBUG("Create all Libs");
   USER_HOST_LEVEL = simgrid::s4u::Host::extension_create(nullptr);
 
-  watched_hosts_lib = xbt_dict_new_homogeneous(nullptr);
-
   xbt_init(argc, argv);
   if (not all_existing_models)
     all_existing_models = new std::vector<simgrid::surf::Model*>();
   if (not future_evt_set)
     future_evt_set = new simgrid::trace_mgr::future_evt_set();
 
-  TRACE_surf_alloc();
-  simgrid::surf::surfExitCallbacks.connect(TRACE_surf_release);
-
   sg_config_init(argc, argv);
 
   if (MC_is_active())
@@ -363,21 +361,17 @@ void surf_exit()
 
   sg_host_exit();
   sg_link_exit();
-  xbt_dict_free(&watched_hosts_lib);
-  for (auto e : storage_types) {
-    storage_type_t stype = e.second;
-    free(stype->model);
-    free(stype->type_id);
-    free(stype->content);
-    xbt_dict_free(&(stype->properties));
+  for (auto const& e : storage_types) {
+    simgrid::surf::StorageType* stype = e.second;
+    delete stype->properties;
     delete stype->model_properties;
-    free(stype);
+    delete stype;
   }
-  for (auto s : *simgrid::surf::StorageImpl::storages)
+  for (auto const& s : *simgrid::surf::StorageImpl::storagesMap())
     delete s.second;
-  delete simgrid::surf::StorageImpl::storages;
+  delete simgrid::surf::StorageImpl::storagesMap();
 
-  for (auto model : *all_existing_models)
+  for (auto const& model : *all_existing_models)
     delete model;
   delete all_existing_models;
 
@@ -388,10 +382,6 @@ void surf_exit()
     future_evt_set = nullptr;
   }
 
-#if HAVE_THREAD_CONTEXTS
-  xbt_parmap_destroy(surf_parmap);
-#endif
-
   tmgr_finalize();
   sg_platf_exit();
   simgrid::s4u::Engine::shutdown();
@@ -440,9 +430,9 @@ double Model::nextOccuringEvent(double now)
 
 double Model::nextOccuringEventLazy(double now)
 {
-  XBT_DEBUG("Before share resources, the size of modified actions set is %zd", modifiedSet_->size());
+  XBT_DEBUG("Before share resources, the size of modified actions set is %zu", modifiedSet_->size());
   lmm_solve(maxminSystem_);
-  XBT_DEBUG("After share resources, The size of modified actions set is %zd", modifiedSet_->size());
+  XBT_DEBUG("After share resources, The size of modified actions set is %zu", modifiedSet_->size());
 
   while (not modifiedSet_->empty()) {
     Action *action = &(modifiedSet_->front());
@@ -559,7 +549,7 @@ void Model::updateActionsStateFull(double /*now*/, double /*delta*/)
 namespace simgrid {
 namespace surf {
 
-Resource::Resource(Model* model, const char* name, lmm_constraint_t constraint)
+Resource::Resource(Model* model, const std::string& name, lmm_constraint_t constraint)
     : name_(name), model_(model), constraint_(constraint)
 {}
 
@@ -644,8 +634,10 @@ Action::~Action() {
   xbt_free(category_);
 }
 
-void Action::finish() {
-    finishTime_ = surf_get_clock();
+void Action::finish(Action::State state)
+{
+  finishTime_ = surf_get_clock();
+  setState(state);
 }
 
 Action::State Action::getState()
@@ -733,13 +725,11 @@ void Action::setMaxDuration(double duration)
     heapRemove(getModel()->getActionHeap());
 }
 
-void Action::gapRemove() {}
-
-void Action::setPriority(double priority)
+void Action::setSharingWeight(double weight)
 {
-  XBT_IN("(%p,%g)", this, priority);
-  priority_ = priority;
-  lmm_update_variable_weight(getModel()->getMaxminSystem(), getVariable(), priority);
+  XBT_IN("(%p,%g)", this, weight);
+  sharingWeight_ = weight;
+  lmm_update_variable_weight(getModel()->getMaxminSystem(), getVariable(), weight);
 
   if (getModel()->getUpdateMechanism() == UM_LAZY)
     heapRemove(getModel()->getActionHeap());
@@ -781,7 +771,8 @@ void Action::suspend()
     lmm_update_variable_weight(getModel()->getMaxminSystem(), getVariable(), 0.0);
     if (getModel()->getUpdateMechanism() == UM_LAZY){
       heapRemove(getModel()->getActionHeap());
-      if (getModel()->getUpdateMechanism() == UM_LAZY  && stateSet_ == getModel()->getRunningActionSet() && priority_ > 0){
+      if (getModel()->getUpdateMechanism() == UM_LAZY && stateSet_ == getModel()->getRunningActionSet() &&
+          sharingWeight_ > 0) {
         //If we have a lazy model, we need to update the remaining value accordingly
         updateRemainingLazy(surf_get_clock());
       }
@@ -795,7 +786,7 @@ void Action::resume()
 {
   XBT_IN("(%p)", this);
   if (suspended_ != 2) {
-    lmm_update_variable_weight(getModel()->getMaxminSystem(), getVariable(), priority_);
+    lmm_update_variable_weight(getModel()->getMaxminSystem(), getVariable(), sharingWeight_);
     suspended_ = 0;
     if (getModel()->getUpdateMechanism() == UM_LAZY)
       heapRemove(getModel()->getActionHeap());
@@ -857,58 +848,5 @@ double Action::getRemainsNoUpdate()
   return remains_;
 }
 
-//FIXME split code in the right places
-void Action::updateRemainingLazy(double now)
-{
-  double delta = 0.0;
-
-  if(getModel() == surf_network_model)
-  {
-    if (suspended_ != 0)
-      return;
-  }
-  else
-  {
-    xbt_assert(stateSet_ == getModel()->getRunningActionSet(), "You're updating an action that is not running.");
-    xbt_assert(priority_ > 0, "You're updating an action that seems suspended.");
-  }
-
-  delta = now - lastUpdate_;
-
-  if (remains_ > 0) {
-    XBT_DEBUG("Updating action(%p): remains was %f, last_update was: %f", this, remains_, lastUpdate_);
-    double_update(&remains_, lastValue_ * delta, sg_surf_precision*sg_maxmin_precision);
-
-    if (getModel() == surf_cpu_model_pm && TRACE_is_enabled()) {
-      simgrid::surf::Resource *cpu = static_cast<simgrid::surf::Resource*>(
-        lmm_constraint_id(lmm_get_cnst_from_var(getModel()->getMaxminSystem(), getVariable(), 0)));
-      TRACE_surf_host_set_utilization(cpu->cname(), getCategory(), lastValue_, lastUpdate_, now - lastUpdate_);
-    }
-    XBT_DEBUG("Updating action(%p): remains is now %f", this, remains_);
-  }
-
-  if(getModel() == surf_network_model)
-  {
-    if (maxDuration_ != NO_MAX_DURATION)
-      double_update(&maxDuration_, delta, sg_surf_precision);
-
-    //FIXME: duplicated code
-    if ((remains_ <= 0) &&
-        (lmm_get_variable_weight(getVariable()) > 0)) {
-      finish();
-      setState(Action::State::done);
-      heapRemove(getModel()->getActionHeap());
-    } else if (((maxDuration_ != NO_MAX_DURATION)
-        && (maxDuration_ <= 0))) {
-      finish();
-      setState(Action::State::done);
-      heapRemove(getModel()->getActionHeap());
-    }
-  }
-
-  lastUpdate_ = now;
-  lastValue_ = lmm_variable_getvalue(getVariable());
-}
-
 }
 }
