@@ -1,4 +1,4 @@
-/* Copyright (c) 2013-2014. The SimGrid Team.
+/* Copyright (c) 2013-2014, 2016-2017. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -46,10 +46,9 @@
 
 static void print_buffer_int(void *buf, int len, char *msg, int rank)
 {
-  int* v;
   printf("[%d] %s (#%d): ", rank, msg, len);
   for (int tmp = 0; tmp < len; tmp++) {
-    v = buf;
+    int* v = buf;
     printf("[%d]", v[tmp]);
   }
   printf("\n");
@@ -69,6 +68,10 @@ int main(int argc, char **argv)
 
   /* Create the buffer */
   MPI_Comm_size(comm, &size);
+  if(size<=0){
+    printf("error : comm size <= 0, run with mpirun\n");
+    return -1;
+  }
   MPI_Comm_rank(comm, &rank);
   int* sbuf = (int *) xbt_malloc(size * size * sizeof(int));
   int* rbuf = (int *) xbt_malloc(size * size * sizeof(int));
